#
# spec file for package linux-glibc-devel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           linux-glibc-devel
Version:        6.8
Release:        1.2
Summary:        Linux headers for userspace development
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            http://www.kernel.org/
Source:         %{name}-%{version}.tar.xz
Source1:        install_all.sh
BuildRequires:  xz
# rpm-build requires gettext-tools; ignore this, in order to shorten cycles (we have no translations)
#!BuildIgnore:  gettext-tools
# glibc-devel requires linux-kernel-headers, which we are in progress of building
#!BuildIgnore:  linux-kernel-headers
PreReq:         coreutils
Provides:       kernel-headers
Provides:       linux-kernel-headers = %{version}
Obsoletes:      linux-kernel-headers < %{version}

%{lua:
function cross_archs()
  return "aarch64", "arm", "hppa", "i386", "m68k", "mips", "ppc64", "ppc64le", "riscv64", "s390x", "sparc", "sparc64", "x86_64"
end

function kernel_arch(arch)
  local map = {
     ["aarch64"] = "arm64",
     ["armv6hl"] = "arm",
     ["armv7hl"] = "arm",
     ["hppa"] = "parisc",
     ["i386"] = "x86",
     ["i586"] = "x86",
     ["i686"] = "x86",
     ["ppc"] = "powerpc",
     ["ppc64"] = "powerpc",
     ["ppc64le"] = "powerpc",
     ["riscv64"] = "riscv",
     ["s390x"] = "s390",
     ["sparc64"] = "sparc",
     ["x86_64"] = "x86",
  }
  return map[arch] or arch
end

function gcc_target(arch)
  local map = {
    ["arm"] = "arm-suse-linux-gnueabi",
    ["i386"] = "i586-suse-linux",
    ["ppc64"] = "powerpc64-suse-linux",
    ["ppc64le"] = "powerpc64le-suse-linux",
  }
  return map[arch] or arch.."-suse-linux"
end
}

%description
This package provides Linux kernel headers, the kernel API description
required for compilation of almost all programs. This is the userspace
interface; compiling external kernel modules requires
kernel-(flavor)-devel, or kernel-syms to pull in all kernel-*-devel,
packages, instead.

%{lua:
  for i,arch in ipairs({cross_archs()}) do
    print(rpm.expand([[

%package -n cross-]]..arch..[[-linux-glibc-devel
Summary:        Linux headers for ]]..arch..[[ userspace cross development
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description -n cross-]]..arch..[[-linux-glibc-devel
This package provides Linux kernel headers for ]]..arch..[[, the kernel API description
required for compilation of almost all programs.
]]))
  end}

%prep
%setup -q -n linux-glibc-devel-%{version}

%build
for karch in *; do
  cd $karch
  cat > version.h <<\BOGUS
#ifdef __KERNEL__
#error "======================================================="
#error "You should not include %{_includedir}/{linux,asm}/ header"
#error "files directly for the compilation of kernel modules."
#error ""
#error "glibc now uses kernel header files from a well-defined"
#error "working kernel version (as recommended by Linus Torvalds)"
#error "These files are glibc internal and may not match the"
#error "currently running kernel. They should only be"
#error "included via other system header files - user space"
#error "programs should not directly include <linux/*.h> or"
#error "<asm/*.h> as well."
#error ""
#error "Since Linux 2.6, the kernel module build process has been"
#error "updated such that users building modules should not typically"
#error "need to specify additional include directories at all."
#error ""
#error "To build kernel modules, ensure you have the build environment "
#error "available either via the kernel-devel and kernel-<flavor>-devel "
#error "packages or a properly configured kernel source tree."
#error ""
#error "Then, modules can be built using:"
#error "make -C <path> M=$PWD"
#error ""
#error "For the currently running kernel there will be a symbolic "
#error "link pointing to the build environment located at "
#error "/lib/modules/$(uname -r)/build for use as <path>."
#error ""
#error "If you are seeing this message, your environment is "
#error "not configured properly. "
#error ""
#error "Please adjust the Makefile accordingly."
#error "======================================================="
#else
BOGUS
  # Get LINUX_VERSION_CODE and KERNEL_VERSION directly from kernel
  cat usr/include/linux/version.h >> version.h
  cat >> version.h <<\BOGUS
#endif
BOGUS
  cd ..
done

%install
cd %{lua:print(kernel_arch(rpm.expand("%_target_cpu")))}
cp -a usr %{buildroot}/
cp -a version.h %{buildroot}%{_includedir}/linux/
cd ..
%{lua:
  for i,arch in ipairs({cross_archs()}) do
    print(rpm.expand([[
sysroot=%{_prefix}/]]..gcc_target(arch)..[[/sys-root
mkdir -p %{buildroot}${sysroot}/%{_includedir}/linux/
cd ]]..kernel_arch(arch)..[[

cp -a usr %{buildroot}${sysroot}
cp -a version.h %{buildroot}${sysroot}/%{_includedir}/linux/
cd ..
]]))
  end}

%pre
if test -L %{_includedir}/asm; then
  rm -f %{_includedir}/asm
fi

%files
%{_includedir}/*

%{lua:
  for i,arch in ipairs({cross_archs()}) do
    print(rpm.expand([[

%files -n cross-]]..arch..[[-linux-glibc-devel
%{_prefix}/]]..gcc_target(arch).."\n"))
  end}

%changelog
* Mon Mar 11 2024 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.8
* Thu Jan 11 2024 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.7
* Mon Oct 30 2023 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.6
* Wed Aug 30 2023 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.5
* Mon Jun 26 2023 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.4
* Thu Apr 27 2023 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.3
* Mon Feb 20 2023 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.2
* Mon Dec 12 2022 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.1
* Mon Oct  3 2022 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 6.0
* Tue Aug  2 2022 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.19
* Tue May 24 2022 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.18
* Tue Mar 22 2022 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.17
* Mon Jan 10 2022 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.16
* Tue Nov  2 2021 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.15
* Wed Sep  1 2021 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.14
* Mon Jun 28 2021 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.13
* Thu May 20 2021 Andreas Schwab <schwab@suse.de>
- Add cross-*-linux-glibc-devel packages
* Tue Apr 27 2021 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.12
* Wed Feb 17 2021 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.11
* Mon Dec 14 2020 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.10
* Mon Oct 12 2020 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.9
* Mon Aug  3 2020 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.8
* Mon Jun 15 2020 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.7
* Tue Mar 31 2020 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.6
* Mon Jan 27 2020 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.5
* Fri Nov 29 2019 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.4
* Wed Sep 18 2019 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.3
- Make it arch dependent due to difference in installed headers
* Mon Jul  8 2019 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.2
* Tue May  7 2019 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.1
* Tue Apr  9 2019 Andreas Schwab <schwab@suse.de>
- Update to kernel headers 5.0
* Mon Jan  7 2019 schwab@suse.de
- Update to kernel headers 4.20
- netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch: remove
* Wed Oct 24 2018 Jiri Slaby <jslaby@suse.cz>
- fix netfilter builds with 4.19
  * add netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch
* Mon Oct 22 2018 schwab@suse.de
- Update to kernel headers 4.19
* Mon Aug 13 2018 schwab@suse.de
- Update to kernel headers 4.18
* Mon Jul 16 2018 schwab@suse.de
- Don't do any expansion on the version.h contents
* Thu Jul 12 2018 bwiedemann@suse.com
- Don't embed build system's kernel version in rpm
  to make package build reproducible (boo#1101107)
* Mon Jun  4 2018 schwab@suse.de
- Update to kernel headers 4.17
* Sun Apr  1 2018 schwab@suse.de
- Update to kernel headers 4.16
* Mon Jan 29 2018 schwab@suse.de
- Update to kernel headers 4.15
- Add support for riscv
* Tue Nov 14 2017 schwab@suse.de
- Update to kernel headers 4.14
* Mon Sep  4 2017 schwab@suse.de
- Update to kernel headers 4.13
* Mon Jul 17 2017 dimstar@opensuse.org
- BuildIgnore linux-kernel-headers: the symbol will only exist once
  the package was built in a bootstrap cycle.
- BuildIgnore gettext-tools: required by rpm-build, but we can
  build without it, allowing to shorten a bootstrap cycle.
* Mon Jul  3 2017 schwab@suse.de
- Update to kernel headers 4.12
* Tue May 16 2017 schwab@suse.de
- Update to kernel headers 4.11
* Fri Mar 10 2017 schwab@suse.de
- Update to kernel headers 4.10
* Wed Jan 11 2017 schwab@suse.de
- Update to kernel headers 4.9
- Remove empty /usr/include/uapi directory
* Thu Oct  6 2016 schwab@suse.de
- Update to kernel headers 4.8
* Thu Aug  4 2016 schwab@suse.de
- Update to kernel headers 4.7
* Wed May 18 2016 schwab@suse.de
- Update to kernel headers 4.6
* Thu Mar 17 2016 schwab@suse.de
- Update to kernel headers 4.5
* Fri Jan 15 2016 mmarek@suse.cz
- Update to kernel headers 4.4
* Mon Nov  9 2015 schwab@suse.de
- Update to kernel headers 4.3
* Tue Oct 13 2015 dvaleev@suse.com
- package back i2c-dev.h the one from i2c-tools is outdated
* Mon Oct 12 2015 dvaleev@suse.com
- Update to kernel headers 4.2
* Fri Jul  3 2015 crrodriguez@opensuse.org
- Update to kernel headers 4.1
* Thu Apr 23 2015 crrodriguez@opensuse.org
- Update to kernel headers 4.0
* Sat Jan 24 2015 jjolly@suse.com
- Only removing /usr/include/scsi/scsi.h (bnc#834498)
* Sun Oct  5 2014 crrodriguez@opensuse.org
- Update to kernel headers from 3.17
* Sun Aug 10 2014 crrodriguez@opensuse.org
- Update to kernel headers from 3.16
* Mon Jun 23 2014 crrodriguez@opensuse.org
- Update to kernel headers from 3.15.1
* Mon Mar 31 2014 crrodriguez@opensuse.org
- Update to kernel headers 3.14
* Tue Mar  4 2014 mmarek@suse.cz
- Update to kernel headers 3.13.
- Drop the never-upstreamed SO_BSDCOMPAT patch. The kernel does
  issue a warning when a process uses this socket option.
* Wed Oct  9 2013 schwab@suse.de
- Don't remove asm-m68k, make link for m68k
* Fri Aug 23 2013 crrodriguez@opensuse.org
- Update to kernel headers from 3.11rc6: not final but
  matches current factory kernel.
* Mon Jul  1 2013 crrodriguez@opensuse.org
- Update to kernel headers from 3.10 final.
* Fri May  3 2013 crrodriguez@opensuse.org
- Update to kernel headers from 3.9 final.
* Tue Mar 26 2013 crrodriguez@opensuse.org
- Update to kernel headers from 3.9rc4
- linux-glibc-devel.SuSE.SO_BSDCOMPAT.patch: needed refresh
  and update due to the addition of SOREUSEPORT
* Sun Feb  3 2013 schwab@suse.de
- Add asm_link for aarch64
* Fri Dec 21 2012 jengelh@inai.de
- Update to new upstream release 3.7.1, use xz format
- Remove unneeded %%clean section
- Also remove sparc's SO_BSDCOMPAT in
  linux-glibc-devel.SuSE.SO_BSDCOMPAT.patch
* Thu Sep 27 2012 coolo@suse.com
- unfuzzy patch to fix build
* Fri Sep 21 2012 crrodriguez@opensuse.org
- Update to Linux 3.6.x headers.
* Tue May 22 2012 aj@suse.de
- Update to Linux 3.4 headers.
  * Remove merged patch getsetattr.patch.
* Wed May 16 2012 aj@suse.de
- Fix typo in version.h (bnc#762486)
* Wed Apr 25 2012 aj@suse.de
- Fix typo: it's __NR_mq_getsetattr
* Mon Mar 19 2012 aj@suse.de
- Update to Linux 3.3 headers.
* Fri Mar 16 2012 aj@suse.de
- Update version.h text (bnc#751668).
* Thu Jan  5 2012 dmueller@suse.de
- update to Linux 3.2.0 headers
  * KVM_CAP_TSC_DEADLINE_TIMER added
* Mon Dec 26 2011 aj@suse.de
- Update to Linux 3.2-rc7 headers.
* Wed Dec 21 2011 dmueller@suse.de
- update to 3.1 headers:
  * fixes missing REQ_META
* Wed Sep  7 2011 aj@suse.de
- Fix LINUX_VERSION_CODE
* Tue Sep  6 2011 aj@suse.de
- Update to Linux 3.1 rc5 headers.
* Mon Jul 25 2011 aj@suse.de
- Update to headers from kernel 3.0.
* Wed Jun 29 2011 aj@suse.de
- Update kernel headers to 3.0 (from 3.0-rc5).
- Remove linux-glibc-devel.SuSE.TIOCGDEV.patch since it's upstream
  now.
- Fix obsoletes.
- Use fdupes.
* Tue Nov 16 2010 coolo@novell.com
- update kernel headers to 2.6.36
- update ioctl patch
* Sun Nov 14 2010 jengelh@medozas.de
- Augment description that not kernel-source is required for
  KMP compilation, but kernel-*-devel.
* Mon Sep 13 2010 coolo@novell.com
- update kernel headers to 2.6.35 for xtables ALIGN
* Sat Jul  3 2010 dmueller@suse.de
- update kernel headers to 2.6.34 for proper O_SYNC support
* Wed Jun 30 2010 jengelh@medozas.de
- add TIOCGDEV define to SPARC definitions
* Tue May 11 2010 pbaudis@suse.cz
- Fix /usr/include/asm symlink loss during upgrade from
  linux-kernel-headers [bnc#591082, bnc#571604]
* Sun Jan 10 2010 coolo@novell.com
- remove -release suffix from provides
* Sun Dec 13 2009 jengelh@medozas.de
- reword Summary line [bnc#340720]
* Tue Dec  8 2009 jengelh@medozas.de
- update to 2.6.32 final (F_OWNER_GID -> F_OWNER_PGRP and other tweaks)
- package header files for SPARC
* Tue Nov 24 2009 rguenther@suse.de
- fix provides and obsoletes fields for linux-kernel-headers
* Mon Nov 16 2009 pbaudis@suse.cz
- add %%ghost entry for /usr/include/asm [bnc#504778]
* Mon Nov 16 2009 pbaudis@suse.cz
- fix provides and obsoletes fields for linux-kernel-headers<=2.6.32-1
* Sat Nov 14 2009 dmueller@suse.de
- update to 2.6.32-rc7
* Sat Nov 14 2009 pbaudis@suse.cz
- remove debug prints [bnc#532066]
* Fri Nov 13 2009 pbaudis@suse.cz
- rename linux-kernel-headers to linux-glibc-devel [bnc#340720]
* Fri Oct 30 2009 dmueller@suse.de
- update to 2.6.32-rc5, matching kernel-source
* Mon Sep 14 2009 coolo@novell.com
- update to 2.6.31-final tar ball - almost no changes
* Mon Aug  3 2009 coolo@novell.com
- avoid conflicting files between glibc-devel and l-k-h
* Sun Aug  2 2009 coolo@novell.com
- update to 2.6.31-rc4 tar ball
* Thu Jul  9 2009 pbaudis@suse.cz
- Remove unnecessary verbosity from %%post phase [bnc#517179]
* Wed Jun 17 2009 coolo@novell.com
- update to 2.6.30
* Fri May 15 2009 pbaudis@suse.cz
- Remove misleading instructions in /usr/include/linux/version.h
  [bnc#498388]
* Fri May  8 2009 coolo@suse.de
- update to 2.6.29
- install with SRCARCH=x86 to get kvm support in qemu
  (detected by presence of kvm.h)
* Mon Feb 23 2009 dmueller@suse.de
- update to 2.6.29rc6
* Wed Feb 18 2009 dmueller@suse.de
- update to 2.6.28
* Fri Sep  5 2008 matz@suse.de
- Remove the kernel version of drm headers, they conflict
  with the libdrm ones, and those are slightly newer.
* Thu Sep  4 2008 matz@suse.de
- update to 2.6.27-rc5, includes new syscalls [bnc #423122]
* Fri Apr 25 2008 pbaudis@suse.cz
- update to 2.6.25
* Mon Jan 28 2008 coolo@suse.de
- fixing changelog
* Sat Jan 26 2008 coolo@suse.de
- fix the x86 path
* Fri Jan 25 2008 olh@suse.de
- update to 2.6.24
  no interface changes
  x86 merge
* Fri Nov  2 2007 dmueller@suse.de
- update to 2.6.23
* Fri Oct 19 2007 ro@suse.de
- bring back i2c.h, i2c-tools only brings i2c-dev.h
  but linux/fb.h needs linux/i2c.h
* Wed Oct 17 2007 jdelvare@suse.de
- Don't include i2c header files, they don't contain everything
  applications need. The proper user-space i2c header files comes
  from the i2c-tools package for now. In the long run, they should
  of course come from sanitized kernel header files as is the case
  for all the other header files, but we're not there yet.
* Mon Aug 13 2007 olh@suse.de
- add triggerpostun to get asm symlink during update (299670)
* Fri Aug 10 2007 olh@suse.de
- include linux/types.h in linux/if_fddi.h to get __be16
* Thu Aug  9 2007 olh@suse.de
- export linux/netfilter/xt_statistic.h for new iptables
  remove __STRICT_ANSI__ check from asm/types to provide __u64
  remove CHILD_MAX again from limits.h
  add a few defines from 2.6.23 to various headers
* Tue Aug  7 2007 olh@suse.de
- really create linux/serial_reg.h
* Tue Aug  7 2007 ro@suse.de
- added coreutils as prereq
* Mon Aug  6 2007 olh@suse.de
- reexport /usr/include/linux/serial_reg.h for xosview (from 2.6.23)
* Mon Aug  6 2007 olh@suse.de
- remove /usr/include/scsi because glibc provides it (297716)
* Sat Jul 14 2007 olh@suse.de
- use linux-2.6.22 as base
- use make headers_install_all to reduce installed package size
- drop all patches except TIOCGDEV and SO_BSDCOMPAT
- mark as noarch and link asm at install time
* Mon May 21 2007 dmueller@suse.de
- Update to match kernel 2.6.21
* Fri Mar  2 2007 pbaudis@suse.cz
- Fix in-tarball paths
* Fri Mar  2 2007 pbaudis@suse.cz
- Update to match kernel 2.6.20
- All architectures are included now
* Fri Nov 17 2006 pbaudis@suse.cz
- Update to match kernel 2.6.18.2
* Sat Oct 28 2006 olh@suse.de
- prevent clueless userspace from trying to get syscall macros
  by defining __KERNEL__ in userland
* Fri Oct 13 2006 schwab@suse.de
- Fix definition of PAGE_SIZE.
* Mon Oct  2 2006 pbaudis@suse.cz
- Update to match kernel 2.6.18
* Fri Sep 29 2006 pbaudis@suse.cz
- Split linux-kernel-headers from glibc (or glibc-devel, if you want)
* Tue Sep 26 2006 pbaudis@suse.cz
- Fix mistake when removing some patches
* Mon Sep 25 2006 pbaudis@suse.cz
- Update to current CVS
* Sat Sep 23 2006 pbaudis@suse.cz
- Fix 64bit-cleanliness gcc warnings
* Thu Sep 21 2006 pbaudis@suse.cz
- Add /usr/lib{,64}/Xaw3d to /etc/ld.so.conf (by schwab@suse.de,
  from original STABLE) [#205169]
- Fix chown() instead of lchown() called in fchownat() emulation
  [#201751]
- Fix glob() overflowing stack when producing massive number of
  matches [#190458]
- Update to current CVS
* Wed Sep 20 2006 pbaudis@suse.cz
- Fix cut'n'paste error in a last-minute change
* Wed Sep 20 2006 pbaudis@suse.cz
- Update to current CVS
- Fix powerpc-cpu tarball extension
- Move crypt-blowfish to a patch so that quilt works on the tree
* Sat Sep  2 2006 schwab@suse.de
- Use asm-powerpc for ppc and ppc64.
- Fix chroot check in glibc_post_upgrade.
* Sun Aug 27 2006 pbaudis@suse.cz
- Update to current CVS, should fix false positive heap overflow
  trigger from malloc() causing gcc to hang [#201724]
* Wed Aug 23 2006 pbaudis@suse.cz
- Update the powerpc cpu-tuned environment to v0.02 [#199274]
- Update to current CVS
- Drop pthread_mutexattr_getprioceiling() out of range fix
* Thu Aug 10 2006 pbaudis@suse.cz
  Ported from STABLE:
- Remove libc5 reference from /etc/ld.so.conf, shlibs5 is no longer
  supported [#181947]
- Fix name of a dummy ia64 header from offsets.h to asm-offsets.h
  [#191394]
* Sun Jul 30 2006 pbaudis@suse.cz
- Update to current CVS snapshot (highlight: support for .gnu.hash
  fast linking support)
* Wed Jul 12 2006 pbaudis@suse.cz
- pthread_mutexattr_getprioceiling() was returning prioceiling out
  of range [#182782]
* Wed Jul 12 2006 pbaudis@suse.cz
- Fix the HTML documentation missing an index [#190585]
* Sat Jun 24 2006 kukuk@suse.de
- Update to current CVS snapshot
- Update to kernel-headers 2.6.17
- Remove HZ define (sysconf(_SC_CLK_TCK) instead)
* Tue Jun 13 2006 kukuk@suse.de
- Update to current CVS snapshot
* Tue May  2 2006 pbaudis@suse.cz
- Fix bad memset() size in NTPL code [#159184]
* Tue May  2 2006 kukuk@suse.de
- asm-powerpc/page.h: Don't move #ifdef __KERNEL__ [#171010]
- bits/mman.h: Fix value of MADV_REMOVE [#170734]
* Mon Apr 24 2006 kukuk@suse.de
- Fix china timezone mess [#163674]
- Don't include linux/stddef.h [#167964]
* Tue Apr 18 2006 schwab@suse.de
- Sanitize <asm-powerpc/sigcontext.h>.
* Thu Apr 13 2006 kukuk@suse.de
- Add /usr/include/linux/taskstats.h [#141936]
* Tue Apr 11 2006 kukuk@suse.de
- nptl/init.c (sigcancel_handler): Compare with correct PID even
  if the thread is in the middle of a fork call.
  (sighandler_setxid): Likewise.
* Sun Apr  9 2006 ihno@suse.de
- S390 fix for startupcode. Part of it was not PIC.
* Fri Apr  7 2006 kukuk@suse.de
- Don't hardcode syscall numbers at our own
* Tue Apr  4 2006 schwab@suse.de
- Fix readlink declaration.
* Mon Apr  3 2006 kukuk@suse.de
- Update from CVS:
  - nscd bug fixes
  - Match return value of readlink to what POSIX says
  - Fix NIS+ checks for NULL pointer
* Sun Apr  2 2006 dmueller@suse.de
- Fix clients crash if nscd is unresponsive (glibc-#2501)
- Fix fd leak in nscd daemon (glibc-#2498)
* Sat Apr  1 2006 schwab@suse.de
- Fix <sys/procfs.h> on ppc64.
* Fri Mar 31 2006 schwab@suse.de
- Extend last change also to ppc64.
* Sun Mar 26 2006 schwab@suse.de
- Terminate FDE before clone syscall.
* Fri Mar 24 2006 ro@suse.de
- kernel-headers: asm-powerpc: define PAGE_MASK in page.h
* Mon Mar 20 2006 kukuk@suse.de
- Update to final 2.6.16 kernel headers
- Update to current CVS:
  - Don't use TLS before setting it up.
  - Fix rounding of long doubles on ppc64.
  - Correct usage of cfi_offset on ppc/ppc64.
  - Fix memory leak in dlopen.
* Tue Mar 14 2006 schwab@suse.de
- Update fnmatch patch.
* Fri Mar 10 2006 kukuk@suse.de
- Disable unshare() syscall (request of kernel developer)
* Fri Mar 10 2006 kukuk@suse.de
- Don't include linux/interrupt.h from linux/rtc.h
- Revert last change to linux/input.h, disable struct
- Update to current CVS (nptl/ia64 fix)
* Thu Mar  9 2006 kukuk@suse.de
- Fix linux/input.h for userspace inclusion
* Wed Mar  8 2006 kukuk@suse.de
- Update kernel headers to 2.6.16-rc5
* Mon Mar  6 2006 kukuk@suse.de
- Update to 2.4 CVS
  - official release
  - Fix free on ppc [#155374]
  - Various sysconf() fixes
* Sat Mar  4 2006 kukuk@suse.de
- Update to CVS
  - ldconfig/prelink fixes
* Fri Mar  3 2006 aj@suse.de
- Do not leave hyphens in defines in create_biarch_asm.sh (Bug 154998).
* Fri Mar  3 2006 kukuk@suse.de
- Update to CVS
  - Fix ftw test suite failures
  - Fix alignment of malloc for long double
* Thu Mar  2 2006 kukuk@suse.de
- Update to 2.3.91 CVS
  - Fix 6arg syscall on s390x
  - memccpy fix on IA64
* Wed Mar  1 2006 kukuk@suse.de
- Update to CVS
  - New linkat interface
  - Update from tzdata2006b
  - Define MADV_DONTFORK and MADV_DOFORK.
  - Add robust mutex to NPTL
* Thu Feb 23 2006 kukuk@suse.de
- Reenable power optimized code again [#142839]
* Sun Feb 12 2006 kukuk@suse.de
- Disable power optimized code
* Thu Feb  9 2006 kukuk@suse.de
- Update to CVS
  - Add unshare prototype
  - Add memory barrier on i386/NPTL
* Wed Feb  8 2006 kukuk@suse.de
- Remove glibc-2.4-ppc-dl-procinfo-20060111.diff [#142839]
* Mon Feb  6 2006 kukuk@suse.de
- Update to current CVS
- Fix alternate locale search path patch [#147685]
* Thu Feb  2 2006 kukuk@suse.de
- Update to current CVS
* Mon Jan 30 2006 schwab@suse.de
- Fix the fix.
* Sat Jan 28 2006 kukuk@suse.de
- Fix seg.fault in __atfct_seterrno if called from futimesat()
- Apply patches for CPU-Tuned Environment on Power [#142839]
* Fri Jan 27 2006 kukuk@suse.de
- Cleanup ld.so.conf
* Thu Jan 26 2006 kukuk@suse.de
- Add alternate directory for translations [#144073]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 kukuk@suse.de
- Update to CVS
- Fix build_locales
* Sat Jan 21 2006 kukuk@suse.de
- Update to CVS
- Fix inclusion of sys/poll.h with _GNU_SOURCE defined
* Fri Jan 20 2006 kukuk@suse.de
- Update to CVS
* Sun Jan 15 2006 kukuk@suse.de
- Update to CVS (fix long double configure check)
* Sun Jan 15 2006 schwab@suse.de
- Readd <fmtmsg.h>, <ucontext.h>, <sys/ucontext.h>.
* Sun Jan 15 2006 schwab@suse.de
- Readd <alloca.h>.
* Sat Jan 14 2006 kukuk@suse.de
- Update to current CVS (long double support)
* Fri Jan 13 2006 aj@suse.de
- Fix x86-64 w_exp to not use extra plt.
* Thu Jan 12 2006 kukuk@suse.de
- Fix asm-s390/setup.h for userspace inclusion
- nsswitch.conf: Add nis to netgroup and automount entry
- Fix sys/procfs.h for ppc64
* Mon Jan  9 2006 kukuk@suse.de
- Update to current CVS (fix for pthread.h with -std=c99)
- Define PAGE_SIZE on POWER
- Don't include linux/sched.h in asm-power/elf.h
* Sun Jan  8 2006 kukuk@suse.de
- Fix linux/acct.h for userland inclusion
* Sun Jan  8 2006 kukuk@suse.de
- Update to current CVS
- Remove CHILD_MAX from kernel-headers
- Copy subdirectories of asm-power, too.
- Remove da_DK@euro (does not exist)
* Sat Jan  7 2006 kukuk@suse.de
- Fix ext2 kernel headers
- Update to current CVS
* Fri Jan  6 2006 kukuk@suse.de
- Update to kernel headers 2.6.15
* Thu Jan  5 2006 kukuk@suse.de
- Update crypt_blowfish to version 1.0
- Update to current CVS
- Adjust nscd patches
* Tue Jan  3 2006 aj@suse.de
- Update to current CVS to fix pthread.h on 64-bit systems for C++.
* Tue Jan  3 2006 aj@suse.de
- Enable string patch again.
- Update to current CVS.
* Wed Dec 21 2005 kukuk@suse.de
- Update to current CVS
- Fix ldconfig
* Sat Dec 17 2005 kukuk@suse.de
- Remove /usr/lib/zoneinfo
- Add /etc/localtime to filelist
- Update to current CVS
- Fix glibc #1978: statvfs does not know about current filesystems
- Fix wrong error return code of time() on x86
- Remove nscd_nischeck
- Remove audit from nfb
- Remove LinuxThreads
* Wed Dec 14 2005 kukuk@suse.de
- Update to current CVS
- Remove nscd_nischeck
- Remove audit from nfb
* Mon Dec  5 2005 kukuk@suse.de
- Update to current CVS
- Disable SELinux
* Thu Nov 24 2005 kukuk@suse.de
- Remove obsolete patches:
  - glibc-2.3.asprintf-error_handling.diff
  - glibc-2.3.90-missing-string_h.diff
* Wed Nov 23 2005 kukuk@suse.de
- Update to current CVS
- Don't install in parallel
* Fri Nov 18 2005 kukuk@suse.de
- Update to current CVS to fix compiling with new binutils
* Wed Nov 16 2005 kukuk@suse.de
- Update to current CVS
* Sat Nov  5 2005 kukuk@suse.de
- Update to current CVS
- Disable linuxthreads on POWER and Itanium
- Fix kernel-headers for userland inclusion
* Wed Nov  2 2005 kukuk@suse.de
- Update to current CVS
- Update to kernel-headers 2.6.14
* Tue Oct 18 2005 kukuk@suse.de
- Update to current CVS
* Sat Oct  1 2005 schwab@suse.de
- Update libm ULPs.
- Fix limit in getcwd.
* Thu Sep 15 2005 kukuk@suse.de
- Update to current CVS
- Update to final 2.6.13 kernel headers
- Adjust bindresvport.blacklist patch to check already ports >= 512
* Fri Aug 26 2005 kukuk@suse.de
- Update to current CVS
- init.d/nscd: Remove -S support (was removed from nscd)
* Fri Aug 19 2005 schwab@suse.de
- Fix comment.
* Fri Aug 19 2005 matz@suse.de
- Change .note.SuSE format [#105825].
* Fri Aug 19 2005 kukuk@suse.de
- Update to current CVS
- Move all obsolete libraries into own subpackage and document
  them as obsolete
* Fri Aug  5 2005 schwab@suse.de
- -mno-tls-direct-seg-refs is x86-only
* Tue Aug  2 2005 kukuk@suse.de
- Update to 2.3.x CVS branch
- Compile with -mno-tls-direct-seg-refs
* Fri Jul 29 2005 kukuk@suse.de
- Update to current CVS head
* Wed Jul 27 2005 schwab@suse.de
- Update libm ULPs for ia64.
- Add linuxthreads stack guard support for ia64.
* Sat Jul 23 2005 kukuk@suse.de
- Update to current CVS head (adds bits/wchar2.h)
- Move LinuxThreads version to obsolete/linuxthreads
* Thu Jul 21 2005 kukuk@suse.de
- Update to current CVS head
* Fri Jul 15 2005 schwab@suse.de
- Fix file list.
* Fri Jul 15 2005 aj@suse.de
- Fix amd64 string routines and math routines.
* Fri Jul 15 2005 kukuk@suse.de
- Use old LinuxThreads only for runtime and remove static version
  and headers
- Update to current CVS head
- Remove own texi2html
* Mon Jul 11 2005 kukuk@suse.de
- Install generic stdio-lock.h header file
* Sat Jul  9 2005 kukuk@suse.de
- Temporary disable AMD64 string optimization
* Wed Jul  6 2005 kukuk@suse.de
- Build and install ja_JP.SHIFT_JISX0213 locale [Bug #84030]
* Mon Jul  4 2005 kukuk@suse.de
- nss_compat: Preserve original return value [Bug #95033]
- Cleanup old Obsoletes/Requires
* Mon Jun 27 2005 kukuk@suse.de
- Update to current gilbc CVS snapshot
* Thu Jun 23 2005 kukuk@suse.de
- Update to current glibc CVS snapshot
- Adjust nscd patch
- Enable SELinux/audit support for nscd
- Update .note.SuSE version
* Mon Jun 20 2005 kukuk@suse.de
- Update to final 2.6.12 kernel headers
- Update to current glibc CVS snapshot
* Thu Jun 16 2005 kukuk@suse.de
- Update linux/audit.h header
- Update to current CVS snapshot
* Mon Jun 13 2005 kukuk@suse.de
- Don't terminate strings twice in nis/netgroup code.
- netinet/if_tr.h: don't include kernel headers.
* Wed Jun  8 2005 kukuk@suse.de
- Update to kernel-headers 2.6.12-rc6
- Fix build on s390 and s390x
* Wed Jun  8 2005 matz@suse.de
- Don't strip .symtab from libpthread.so.0 (and other libs).
  Fixes debugging of threaded programs (#81253).
* Mon Jun  6 2005 kukuk@suse.de
- Update to current CVS head
- Update to kernel-headers 2.6.12-rc5
* Thu May 26 2005 schwab@suse.de
- No longer build loadlocale.c with -fno-unit-at-a-time.
* Tue May 24 2005 kukuk@suse.de
- Update to current CVS head, obsoletes:
  - glibc-2.3.90-libm.diff
  - glibc-2.3.90-i386-sysdep.diff
  - warn.diff
  - dl-osinfo.diff
  Adjusted:
  - glibc-2.3.90-bindresvport.blacklist.diff
* Sat May 21 2005 schwab@suse.de
- Fix missing include.
* Tue May 17 2005 schwab@suse.de
- Fix warning.
* Fri Apr 29 2005 kukuk@suse.de
- Update to latest CVS snapshost
* Sat Apr 23 2005 kukuk@suse.de
- Fix all the archs using wrong FLAGS
* Sat Apr 23 2005 kukuk@suse.de
- Remove -D_FORTIFY_SOURCE from RPM_OPT_FLAGS
* Fri Apr 22 2005 kukuk@suse.de
- Update to current CVS
* Fri Apr 22 2005 kukuk@suse.de
- Check if nice value does not conflict with test suite
* Tue Apr 19 2005 mls@suse.de
- resolv: trigger re-read of /etc/resolv.conf for all threads if
  a change is detected
- nscd: support a negative timeout of zero, used by hosts cache
* Mon Apr 18 2005 meissner@suse.de
- Enable fortify possibility even for GCC 4.0, we apply
  the necessary patch to the SUSE GCC 4.0.
* Sat Apr 16 2005 aj@suse.de
- Apply amd64 string diff again.
* Tue Apr 12 2005 kukuk@suse.de
- Update kernel-headers to 2.6.10
- Update to current CVS snapshot
* Wed Apr  6 2005 schwab@suse.de
- Cleanup neededforbuild.
* Tue Apr  5 2005 aj@suse.de
- Add gettext-devel to neededforbuild.
* Tue Apr  5 2005 aj@suse.de
- Do not build on xen machines.
- Adjust libm ULPs for PowerPC.
* Fri Apr  1 2005 kukuk@suse.de
- Update to current CVS snapshot
* Tue Mar 29 2005 kukuk@suse.de
- Update to current CVS snapshot
- Fix compiler warnings on ix86
* Mon Mar 28 2005 kukuk@suse.de
- Update to current CVS snapshot
- Disable Noversion Patch on i386 temporary
* Fri Mar 18 2005 ro@suse.de
- check-build.sh: require 2.6.11 on x86,x86_64 for build
* Thu Mar 17 2005 mls@suse.de
- nscd: enable hosts cache
- nscd: also watch /etc/resolv.conf
- nscd: check files every 3 seconds
- nscd: deal correctly with missing files
* Tue Mar 15 2005 kukuk@suse.de
- Update to current CVS snapshot.
* Sat Feb 12 2005 schwab@suse.de
- Remove const from __pthread_internal_tsd_address.
* Fri Feb 11 2005 schwab@suse.de
- Update to current CVS.
- Link glibc_post_upgrade against new libc.
- Fix build error with gcc4.
* Wed Feb  9 2005 kukuk@suse.de
- Update to current CVS
- Fix bindresvport blacklist handling.
- Increase buffer in tst-cancel17 to match new kernel buffer size
  [#50277]
- Enable LinuxThreads again
- Remove ia64-audit patch (is upstream)
* Mon Feb  7 2005 aj@suse.de
- Add patch to allow compilation with gcc4.
* Mon Jan 31 2005 schwab@suse.de
- Readd support for LD_AUDIT on ia64.
* Mon Jan 31 2005 kukuk@suse.de
- Add memory clobber to string inline assemblies on s390 [#50284].
* Mon Jan 31 2005 kukuk@suse.de
- Fix filelist on i686 if we build NPTL only version
* Mon Jan 31 2005 aj@suse.de
- Generate new ULPs file for i386 needed by GCC 4.
* Sun Jan 30 2005 kukuk@suse.de
- Include own copy of texi2html
- Add glibc_pst_upgrade program (based on version from FC3)
- Update to current CVS
* Thu Jan 27 2005 kukuk@suse.de
- Re-add patch for timezone/zic.c (got lost with last merge)
* Wed Jan 26 2005 kukuk@suse.de
- Update timezone data to 2005c release (fixes zdump crash on
  64bit architectures)
* Sat Jan 22 2005 schwab@suse.de
- Add basic (incomplete) support for LD_AUDIT on ia64.
* Fri Jan 21 2005 kukuk@suse.de
- Enable patch for [Bug #49833]
- Allow to build NPTL only glibc
- Update to CVS from Jan 16, 2005, containing:
- Fix execlp argument in SunRPC code [glibc #681]
- Fix errno return values for futimes [glibc #633]
- Update FPU function on PPC/PPC64 [Bug #49764]
* Mon Jan 17 2005 aj@suse.de
- Enable amd64 string patch again after fixing failing hunks.
- Handle missing cpuid better for amd64 string functions. [#49803]
* Sat Jan 15 2005 aj@suse.de
- Fix amd64 string patch to use correct datatype.
* Fri Jan 14 2005 kukuk@suse.de
- Fix memory corruption in getgrouplist function [Bug #49833]
* Tue Jan 11 2005 kukuk@suse.de
- Enable all LinuxThreads tests again
- Finalize getconf -a patch (make it compatible with Solaris)
- Rewrite getconf manual page and mention new option
- Merge GB18030 patches into one.
* Thu Dec 30 2004 kukuk@suse.de
- Merge kernel-headers.remove-SO_BSDCOMPAT.diff with
  kernel-headers.SuSE.diff
- Revert nscd paths on old SuSE Linux distributions
* Wed Dec 29 2004 kukuk@suse.de
- Update to glibc 2.3.90 CVS branch
- Remove alarm-round.patch (merged upstream)
* Thu Dec  9 2004 kukuk@suse.de
- Update to current CVS
- Move nscd persistent database files back to /var/run/nscd
* Mon Dec  6 2004 kukuk@suse.de
- Update to current CVS
- Fix more kernel headers for userland inclusion
* Fri Nov 26 2004 ro@suse.de
- kernel-headers.diff: define __force in compiler.h
* Thu Nov 25 2004 schwab@suse.de
- Add Intel libm update.
* Thu Nov 25 2004 kukuk@suse.de
- Update to current glibc CVS
- Update kernel headers to 2.6.9
* Thu Nov 18 2004 kukuk@suse.de
- Update to current glibc CVS
* Mon Nov 15 2004 kukuk@suse.de
- Update to current glibc CVS
* Mon Nov  8 2004 kukuk@suse.de
- Blacklist port 921 (lwresd) for usage by bindresvport()
- Update to current glibc CVS
- Add /var/run/nscd/* files as ghost entries
* Mon Oct 18 2004 aj@suse.de
- Don't use special fdim functions for x86-64 since those give
  wrong results for fdim (inf,inf).
- Fix ppc64 rebuild issue with ppc32 system [#47325].
* Wed Oct 13 2004 kukuk@suse.de
- Fix symlink librt.so -> tls/librt.so.1
- Backout last glob changes
- Disable nptl as default for linking
* Tue Oct 12 2004 kukuk@suse.de
- Install kernel-headers after merging linuxthreads/NPTL headers
* Tue Oct 12 2004 kukuk@suse.de
- Update to current CVS snapshot
* Mon Oct 11 2004 kukuk@suse.de
- Make NPTL default for linking
* Fri Oct  1 2004 kukuk@suse.de
- Update to current CVS snapshot
- Add workaround for linuxthreads/without-__threads bug
- Remove KDE/ldconfig workaround
- Set SuSE ABI note to 9.3
* Sun Sep 26 2004 kukuk@suse.de
- Add lib/nptl/librt.so symlink to tls/librt.so.1
- Update to current CVS
* Sat Sep 25 2004 kukuk@suse.de
- Implement mq support for rtkaio and enable it again
* Fri Sep 24 2004 kukuk@suse.de
- Add zh_SG.UTF-8 [Bug #46024]
* Thu Sep 23 2004 kukuk@suse.de
- Sync sys/mount.h and linux/fs.h
* Wed Sep 22 2004 kukuk@suse.de
- Make mdns support configurable in /etc/host.conf
* Mon Sep 20 2004 kukuk@suse.de
- Fix invalidating of nscd caches and getaddrinfo()
* Fri Sep 17 2004 kukuk@suse.de
- Update to current CVS (nscd and glob.h fixes)
* Thu Sep 16 2004 kukuk@suse.de
- Fix getaddrinfo/nscd support
* Wed Sep 15 2004 kukuk@suse.de
- Update to current CVS, remove merged patches
* Sun Sep 12 2004 kukuk@suse.de
- Update to CVS: Fix nscd crash if one service is disabled
- glob.h: Add workaround for invalid prototypes
- nss_compat: Check that buffer is larger than 0 bytes
* Fri Sep 10 2004 kukuk@suse.de
- Update to CVS: Fix cdefs.h for C++ usage
* Fri Sep 10 2004 kukuk@suse.de
- Add lwres to hosts search order in nsswitch.conf
- Update to current CVS
- Use new nscd paths for socket/pid file
- Enable NPTL on i586
- Add --print-all option to getconf
* Thu Sep  2 2004 kukuk@suse.de
- Fix NPTL header files on x86-64 for 32bit compilation
- Apply various fixes from CVS
- Remove pre-Install for -devel package (no longer necessary)
* Wed Aug 25 2004 kukuk@suse.de
- Don't compile in eval.c
* Mon Aug 23 2004 kukuk@suse.de
- Update to current CVS:
  - Use CVS version for last fix.
  - Add malloc sanity checks for double free.
* Fri Aug 20 2004 schwab@suse.de
- Fix cancellable syscalls in librt w/ linuxthreads.
* Fri Aug 20 2004 kukuk@suse.de
- Update to current CVS [#43993]
* Thu Aug 19 2004 schwab@suse.de
- Better fix for asm-ia64/gcc_intrin.h.
* Wed Aug 18 2004 kukuk@suse.de
- Update to current CVS
- Workaround linux/ixjuser.h problem not including compiler.h
- Workaround linux/capi.h problem not including compiler.h
* Tue Aug 17 2004 schwab@suse.de
- Fix asm-ia64/gcc_intrin.h.
* Tue Aug 17 2004 kukuk@suse.de
- Workaround broken linux/crc-ccitt.h for usage from glibc [#43884]
* Mon Aug 16 2004 kukuk@suse.de
- Update to current CVS version and update to
  kernel-headers 2.6.8.1 to fix NPTL deadlock problems
- Disable linuxthreads/tst-clock1, does not work on i586 and lower
* Fri Aug 13 2004 kukuk@suse.de
- Update to current CVS version
- Cleanup/adjust all patches
* Thu Jun 17 2004 kukuk@suse.de
- Fix sched_setaffinity return/errno code in error case [#42124]
* Wed Jun 16 2004 meissner@suse.de
- Updated altivec set/get/swapcontext patch to fix
  more problems on altivec capable machines [#42039].
- glibc is also able to build on -pmac64 kernels.
* Mon Jun 14 2004 kukuk@suse.de
- Add fixes from CVS:
  - sysconf return value fixes
  - nscd host caching deadlock
  - backtrace for s390/s390x/ia64 static linked binaries
* Mon Jun 14 2004 kukuk@suse.de
- Increase listen backlog in RPC code [#41955]
* Wed Jun  9 2004 meissner@suse.de
- Fixed typos in powerpc* *context functions to not destroy the r19
  register and save the v19 register correctly. [#41790]
* Sat Jun  5 2004 aj@suse.de
- Fix makecontext with more than 6 arguments on x86-64 [#40546].
* Mon May 24 2004 kukuk@suse.de
- Update to kernel-headers 2.6.6
- Update to current glibc CVS
- Disable rtkaio temporary
* Sun May 23 2004 kukuk@suse.de
- Fix pthread_cond_wait on not ix86 and x86-64 architectures
* Thu May 20 2004 kukuk@suse.de
- Add PPC64 kernel header file fixes [#40831,#40870]
* Wed May 19 2004 kukuk@suse.de
- Add additional NPTL fixes from CVS
* Tue May 18 2004 schwab@suse.de
- Fix mapping of DSOs with holes.
* Fri May 14 2004 schwab@suse.de
- Fix rounding in alarm [#40552].
* Wed May 12 2004 schwab@suse.de
- Fix uninitialized array in regexp compiler [#40009].
* Tue May 11 2004 kukuk@suse.de
- Apply lot of fixes from current CVS
- Fix alignment of stack for makecontext on x86-64 [Bug #39413]
- Make XTABS identical to TABDLY on PPC
* Wed May  5 2004 kukuk@suse.de
- Add some header fixes to match POSIX
* Tue May  4 2004 meissner@suse.de
- Fix INLINE_SYSCALL on ppc and ppc64 (see #38399)
* Mon May  3 2004 kukuk@suse.de
- Port --mlock option for ld.so from UL1 [Bug #39569]
* Tue Apr 20 2004 kukuk@suse.de
- Add execstack fix for s390
* Mon Apr 19 2004 kukuk@suse.de
- Update to current CVS version (fix problems with new binutils
  and gcc)
* Mon Apr 19 2004 kukuk@suse.de
- Add pthread_getattr_np and syslog fixes from CVS
- Update gb18030 and big5hkscs gconv modules [Bug #39080]
* Sat Apr 17 2004 schwab@suse.de
- Pacify autobuild.
* Thu Apr 15 2004 kukuk@suse.de
- Add /etc/ld.so.conf.d/*.conf to /etc/ld.so.conf
- Disable FUTEX_REQUEUE support in NPTL library [Bug #38882]
* Wed Apr 14 2004 schwab@suse.de
- Remove /usr/i386-linux from ld.so.conf,
* Wed Apr 14 2004 kukuk@suse.de
- Fix linux/compiler.h for glibc inclusion
- Really fix ffsl on s390x
* Fri Apr  9 2004 schwab@suse.de
- Fix syntax error in memcmp.
* Fri Apr  9 2004 kukuk@suse.de
- Update from CVS: linuxthread debug fixes
- Fix INLINE_SYSCALL on x86-64 and ia64 (fixes #38399)
- Fix ffsl weak alias on s390x
- Update to 2.6.5 kernel headers
* Wed Apr  7 2004 meissner@suse.de
- forward umount to umount2 on ppc64 because umount syscall
  does not exist
* Mon Apr  5 2004 kukuk@suse.de
- Sync with current CVS (which is nearly identical with most of
  our latest patches)
* Fri Apr  2 2004 kukuk@suse.de
- Make fstatvfs64 working on 32bit architectures
- Add fwrite LFS fix from aj
- Add powerpc fixes from CVS
- Fix wrong errno code for shm_unlink [Bug #38013]
* Wed Mar 31 2004 kukuk@suse.de
- Add three fixes from CVS:
  - Call __nptl_deallocate_tsd for main thread, too
  - setgroups: optimizations for huge number of groups
  - initgroups: Limit the initial allocation to 64 entries
* Tue Mar 30 2004 kukuk@suse.de
- Add IUTF8 to bits/termios.h [Bug #34725]
- *affinitiy.c: Prepend GLIBC_ to version names
* Sat Mar 27 2004 kukuk@suse.de
- Fix wrong return value of getXXbyYY_r in case key was not
  found [Bug #37181]
- Fix typo in dl-open
- Don't set errno in NSS NIS module if group was not found
* Fri Mar 26 2004 aj@suse.de
- Add pow10/pow10f aliases for AMD64.
* Thu Mar 25 2004 kukuk@suse.de
- Update to latest CVS snapshot
* Sat Mar 20 2004 aj@suse.de
- Fix further problems with sched_[sg]etaffinity calls.
* Fri Mar 19 2004 aj@suse.de
- Fix sched_setaffinity compile problem.
* Fri Mar 19 2004 kukuk@suse.de
- Remove conflict with special aaa_base version (rpm will handle
  this with file conflict)
* Fri Mar 19 2004 kukuk@suse.de
- Add SuSE abi note
- Add madvise patch
- Update to current CVS
* Wed Mar 17 2004 kukuk@suse.de
- Use official NPTL version fix
- Add LD_DEBUG=statistic for x86-64
- Fix two JB_SIZE redefinitions on PPC
- Add two fixes for execstack
* Mon Mar 15 2004 kukuk@suse.de
- Require kernel 2.6.4 for glibc/NPTL
- Remove siginfo_t/si_band patch (needs to be fixed in kernel)
- Update linuxthreads_db and nptl_db
- Add libidn fixes from CVS
* Sat Mar 13 2004 kukuk@suse.de
- Adjust filelist (remove libcidn.a and libcidn_p.a)
* Sat Mar 13 2004 kukuk@suse.de
- Update to current CVS (merge of patches)
- Fix siginfo_t/si_band [Bug #34330]
* Thu Mar 11 2004 mls@suse.de
- Add mdns support to resolver library
* Thu Mar 11 2004 kukuk@suse.de
- Update kernel headers to 2.6.4
- Update to current glibc CVS
* Wed Mar 10 2004 bg@suse.de
- Update hppa patches.
* Mon Mar  8 2004 kukuk@suse.de
- Fix vDSO on IA64
* Mon Mar  8 2004 kukuk@suse.de
- Update from glibc CVS:
  - Add libidn
  - Lot of dynamic loader changes
* Thu Mar  4 2004 kukuk@suse.de
- Update from glibc CVS:
  - Fix posix_fadvise vs. posix_fadvise64
* Tue Mar  2 2004 kukuk@suse.de
- Fix PPC kernel header files
- Update from glibc CVS
  - NPTL fixes
  - nscd fixes
* Tue Mar  2 2004 schwab@suse.de
- Fix ppc32 to always use stat64 syscall.
* Sat Feb 28 2004 kukuk@suse.de
- Update from glibc CVS:
  - Fix compiler warnings
  - NPTL: Don't use CLONE_STOPPED
  - Revert vDSO changes
* Fri Feb 27 2004 kukuk@suse.de
- Update from glibc CVS:
  - Real NGROUP_MAX fix
  - Lot of NPTL fixes
  - clock_settime fix
- Add no_NO back (required by OpenI18N spec and [Bug #34745])
* Thu Feb 26 2004 kukuk@suse.de
- Workaround broken NGROUP_MAX function
* Thu Feb 26 2004 kukuk@suse.de
- Add insserv PreRequires for nscd
- Update from CVS: NPTL and getaddrinfo memory leak fixes,
  Get NGROUP_MAX from /proc filesystem
* Sat Feb 21 2004 kukuk@suse.de
- Update from CVS: IA64 relo fix, lot of PPC fixes
- Fix linux/mod_devicetable.h for userland inclusion
- Enable NPTL on Alpha
* Fri Feb 20 2004 schwab@suse.de
- Fix pthread_barrier_wait.
* Thu Feb 19 2004 kukuk@suse.de
- Update from CVS: More NPTL fixes
- nscd.init: Cleanups
* Wed Feb 18 2004 kukuk@suse.de
- Kernel Headers: Fix asm-ppc/unaliged.h, asm-ppc/types.h and
  asm-ppc/bitops.h for userland inclusion.
* Wed Feb 18 2004 bg@suse.de
- Update hppa patches for current glibc
- Add workaround for ICE in hppa
* Tue Feb 17 2004 kukuk@suse.de
- Update from CVS:
  - PPC nptl compatiblity fix
  - NSCD patches merged
  - ld.so.preload: Igreno missing files
  - getaddrinfo: Fix problem with IPv6 addresses
* Tue Feb 17 2004 aj@suse.de
- Fix string optimizations init code on AMD64.
* Sat Feb 14 2004 kukuk@suse.de
- Update from CVS (for NPTL fixes and new PPC longjmp)
- Fix nscd deadlock with kernel 2.6 [Bug #34507]
* Fri Feb 13 2004 aj@suse.de
- Add more string/memory optimizations for AMD64.
* Thu Feb 12 2004 kukuk@suse.de
- Fix regex bug with invalid UTF-8 strings
* Thu Feb 12 2004 aj@suse.de
- Add more string optimizations for AMD64.
* Wed Feb 11 2004 kukuk@suse.de
- Update to current CVS snapshot
- Fix _IOC_TYPECHECK on s390/s390x/parisc
- Compile rtkaio only with NPTL
- Remove glibcbug (was dropped since glibc uses bugzilla now)
- Disable parallel build on s390x
* Tue Feb 10 2004 schwab@suse.de
- Work around invalid use of kernel headers in some packages.
* Fri Feb  6 2004 kukuk@suse.de
- Add kernel stat fix for PPC
- Add fix for off-by-one error in regex code
* Thu Feb  5 2004 kukuk@suse.de
- Update kernel header files to 2.6.2
* Tue Feb  3 2004 bg@suse.de
- Update hppa patch
* Tue Feb  3 2004 kukuk@suse.de
- Fix ypclnt speedup patch
- Update to current CVS snapshot
* Mon Jan 26 2004 kukuk@suse.de
- Update to current CVS snapshot
* Wed Jan 21 2004 aj@suse.de
- Do not run in parallel on s390.
* Mon Jan 19 2004 ro@suse.de
- really fix linux/percpu.h to compile in userland
* Fri Jan 16 2004 kukuk@suse.de
- Update version.h to 2.6.1
- Fix linux/percpu.h to compile in userland
- Update to current CVS snapshot
- Revert nscd path changes
* Wed Jan 14 2004 kukuk@suse.de
- Update to Kernel Headers 2.6.1
- Update to current CVS snapshot
- Don't ignore make check on IA64 any longer
* Sat Jan 10 2004 schwab@suse.de
- Locale no_NO has been renamed to nb_NO.
* Fri Jan  9 2004 kukuk@suse.de
- Temporary ignore make check on IA64 and PPC
  (known kernel/compiler bugs)
* Thu Jan  8 2004 stepan@suse.de
- fix v4l2 headers
* Wed Jan  7 2004 kukuk@suse.de
- Update to glibc CVS from 20040107
- Remove manual pages which are now part of man-pages
* Thu Dec 18 2003 kukuk@suse.de
- Update to glibc CVS from 20031218
- Update ot final 2.6.0 kernel headers
- Fix syntax error in spec file
- Update HPPA patch
* Mon Dec 15 2003 kukuk@suse.de
- Update to glibc CVS from 20031215
* Fri Dec 12 2003 kukuk@suse.de
- Update to glibc CVS from 20031212
- disable rtkaio (does not work with kernel 2.6 yet)
* Fri Dec  5 2003 kukuk@suse.de
- Update to glibc 2.3.3 CVS
- Make an extra sub package for nscd
* Thu Nov 27 2003 kukuk@suse.de
- Update to glibc CVS from 20031127
- Add nsswitch.conf (moved from aaa_base)
- Add ld.so.conf (moved from aaa_base) [Bug #33277]
- Fix ceil on AMD64
* Fri Nov 21 2003 kukuk@suse.de
- Update to glibc CVS from 20031121
- Obsolete epoll (glibc-devel contains now this header files)
* Wed Nov 19 2003 kukuk@suse.de
- Add patch so that ld.so supports linuxthreads and nptl
- PPC64 requires kernel 2.4.21
- Update to glibc CVS from 20031119
* Fri Nov 14 2003 bg@suse.de
- Add hppa patches for current glibc.
* Fri Nov 14 2003 kukuk@suse.de
- Update to glibc CVS from 20031114
- Remove PPC64 symbol version patch
* Thu Nov 13 2003 schwab@suse.de
- Fix last change covering libNoVersion.
* Mon Nov 10 2003 schwab@suse.de
- Specfile cleanup.
* Thu Nov  6 2003 kukuk@suse.de
- Update to glibc CVS from 20031106
* Wed Nov  5 2003 uli@suse.de
- added a number of ARM fixes (glibc-2.3.2-armformat.patch,
  glibc-armisa.patch, glibc-sjlj.patch)
* Mon Oct 27 2003 kukuk@suse.de
- Update to glibc CVS from 20031027
- kernel headers: update to 2.6.0-test9
- nptl: Use -fno-unit-at-a-time on AMD64, too
* Thu Oct 23 2003 kukuk@suse.de
- Update to current CVS version
* Wed Oct 22 2003 kukuk@suse.de
- nptl: Fix prototype in configure script
- nptl: Use -fno-unit-at-a-time
- locale: Add nb_NO
* Fri Oct 17 2003 kukuk@suse.de
- Increase timeout for make check on overloaded architectures
* Thu Oct 16 2003 kukuk@suse.de
- Fix building as normal user
* Wed Oct 15 2003 kukuk@suse.de
- Fix putpwent/putgrent
- Make build as normal user
* Tue Oct 14 2003 kukuk@suse.de
- Update to glibc CVS from 20031014
* Tue Oct 14 2003 aj@suse.de
- Fix w_acosf for AMD64.
* Tue Oct 14 2003 kukuk@suse.de
- Fix asm-sparc/kbio.h to compile kbdrate/X11
* Mon Oct 13 2003 kukuk@suse.de
- Update to kernel header files from 2.6.0-test7
* Fri Oct 10 2003 schwab@suse.de
- Fix misnamed syscalls.
* Tue Oct  7 2003 kukuk@suse.de
- Update to glibc CVS from 20031007
* Fri Oct  3 2003 kukuk@suse.de
- Update to glibc CVS from 20031003
- Fix kernel ioctl header files for PPC/PPC64
- Removed dl-reloc.c fix, merged upstream
* Wed Oct  1 2003 kukuk@suse.de
- Update to glibc cvs from 20031001
- Remove sysmacros.h fix, merged upstream
- Add dl-reloc.c fix for compiler warnings
* Mon Sep 29 2003 kukuk@suse.de
- Update kernel-headers to 2.6.0-test6
- Fix sysmacros.h to compile with -ansi
* Sat Sep 27 2003 kukuk@suse.de
- Update to glibc CVS from 20030927
- Remove SO_BSDCOMPAT (obsoleted by kernel)
- Make _IOC_TYPECHECK useable for userland programs
* Fri Sep 26 2003 kukuk@suse.de
- Remove obsolete patches
- Update to crypt_blowfish 0.4.5
* Fri Sep 26 2003 kukuk@suse.de
- Update to glibc CVS from 20030926
- Update to nptl 0.60
* Sat Sep 20 2003 kukuk@suse.de
- Update to glibc CVS from 20030920
- Update to nptl 0.59
* Wed Sep 17 2003 kukuk@suse.de
- Disable TLS for i586 glibc [Bug #31034]
* Tue Sep 16 2003 kukuk@suse.de
- Remove db1.85
* Mon Sep 15 2003 kukuk@suse.de
- Update to glibc CVS from 20030915
* Mon Sep 15 2003 kukuk@suse.de
- Update to kernel 2.6.0-test5 header files
* Sat Sep 13 2003 kukuk@suse.de
- Add librtkaio, a librt using kernel aio
* Thu Sep 11 2003 kukuk@suse.de
- Update to current CVS
- Remove patches which are merged in CVS
- Update to nptl-0.58
- Remove _POSIX_VERSION hack
* Thu Sep 11 2003 kukuk@suse.de
- version.h: Fix comment how to compile kernel modules
* Wed Sep 10 2003 aj@suse.de
- Install en_US.ISO-8859-15 under this name [#30373].
* Tue Sep  9 2003 aj@suse.de
- Fix last patch.
* Mon Sep  8 2003 aj@suse.de
- Fix setting up of user signal handler in linuxthreads on x86_64.
* Fri Sep  5 2003 kukuk@suse.de
- Add dl-tls.c to fix out of memory with static TLS errors
* Wed Sep  3 2003 kukuk@suse.de
- Update glibc-linuxthreads
- Set _POSIX_VERSION back to 199209
* Mon Sep  1 2003 kukuk@suse.de
- Fix typo in nss_compat patch
* Mon Sep  1 2003 kukuk@suse.de
- Add opendir fix for usage with NPTL
- Fix getspnam/getspent in nss_compat [Bug #29689]
- Set _POSIX2_VERSION back to 199209
* Wed Aug 27 2003 kukuk@suse.de
- Update to current CVS version
* Mon Aug 25 2003 kukuk@suse.de
- Update to current CVS version
* Mon Aug 18 2003 aj@suse.de
- increase stack size for linuxthreads/set-context.
* Mon Aug 18 2003 aj@suse.de
- Fix mathinline.h for i386 to compile under C++ without warnings.
* Sun Aug 17 2003 ro@suse.de
- kernel-headers.dif: don't include device.h from videodev.h
* Fri Aug 15 2003 kukuk@suse.de
- Update to current cvs (fixes assert usage in C++ source code)
* Thu Aug 14 2003 kukuk@suse.de
- Initialize fp->_mode for glibc 2.0 compatibility [Bug #28386]
- On i686, include glibc with and without floating stack enabled
- Update to current cvs
- Update to nptl 0.56
* Thu Jul 31 2003 kukuk@suse.de
- Reenable new quota.h
* Wed Jul 30 2003 kukuk@suse.de
- Update to current cvs
- Update kernel headers to 2.6.0-test2
- Disable sys/quota.h update
- Enable TLS on AMD64 again
* Mon Jul 28 2003 kukuk@suse.de
- Update to current cvs
- Disable TLS on AMD64 temporary
- Update sys/quota.h to match new kernel implementation
* Fri Jul 25 2003 kukuk@suse.de
- Update to current cvs
- Update kernel headers to 2.6.0-test1
- Update to nptl 0.55
- Change minimal symbol version on PPC64 back to 2.2.5
* Wed Jul 23 2003 meissner@suse.de
- Fixed systemcall clobber lists for asm-ppc/unistd.h (by just
  merging over the asm-ppc64 things).
* Wed Jul 23 2003 aj@suse.de
- Handle in ldconfig konqueror.so and other similar KDE hacks that fail without
  rpath.
- Fix bugs exposed by unit-at-a-time option.
* Fri Jul 18 2003 aj@suse.de
- Fix compilation with unit-at-a-time enabled compiler.
- Enlarge stack for tst-setcontext test.
* Mon Jun 30 2003 kukuk@suse.de
- Update to current CVS (includes if_arp.h and nss_compat changes)
- Update to nptl 0.50
- Kernel header fixes for userland inclusion
* Wed Jun 25 2003 kukuk@suse.de
- Update to current CVS
- Add target host and CVS checkout to glibc version printout
- Adjust fnmatch fix
- Update kernel headers to 2.5.73
* Tue Jun 24 2003 kukuk@suse.de
- Fix typos in syscalls.list on Alpha
* Mon Jun 23 2003 kukuk@suse.de
- fix typo in linuxthreads on SPARC
- Update to current CVS
- Update to nptl 0.48
* Thu Jun 19 2003 kukuk@suse.de
- Disable nss_compat patch again
* Wed Jun 18 2003 kukuk@suse.de
- Fix reading of locale.alias file
- Update to current CVS snapshot
- Update to nptl 0.47
- Some kernel header file fixes for PPC64/IA64
- Update nss_compat patch
* Thu Jun 12 2003 kukuk@suse.de
- Update to current CVS snapshot
- Finish patch for printing linker warning
* Wed Jun 11 2003 kukuk@suse.de
- Update to nptl 0.45
- Update to current CVS snapshot
- Add patch to print linker warning, if a static binary calls
  functions using NSS
* Tue Jun 10 2003 kukuk@suse.de
- Use %%find_lang macro and cleanup glibc-locale filelist
* Thu Jun  5 2003 kukuk@suse.de
- Complete mathinline.h fixes
* Thu Jun  5 2003 kukuk@suse.de
- linux/compiler.h: Define all inline variants to __inline__
* Wed Jun  4 2003 kukuk@suse.de
- Update to current glibc CVS snapshot
- Update to nptl 0.43
- More kernel header fixes
- Make --no-archive default for localedef
* Tue May 27 2003 kukuk@suse.de
- Update to current glibc CVS snapshot
- Update to nptl 0.40
- Disable nss_compat patch
- Update to kernel headers from 2.5.70
* Fri May 23 2003 kukuk@suse.de
- Update to current glibc CVS snapshot
- Add patches to make nss_compat work with every service
* Mon May 19 2003 kukuk@suse.de
- Update to current glibc CVS snapshot
- Add patch for better binary compatibility (errno, h_errno)
* Fri May 16 2003 kukuk@suse.de
- Update to current glibc CVS snapshot
- Update to nptl 0.39
- Add URL tag
- asm-i386/byteorder.h: fix asm vs. __asm__
* Wed May 14 2003 schwab@suse.de
- Fix missing syscall numbers on ia64.
* Wed May 14 2003 kukuk@suse.de
- More kernel headers fixes for i386, ia64, ppc and s390
* Mon May 12 2003 kukuk@suse.de
- Update to current glibc CVS snapshot
- Fix lot of more kernel headers
- Adjust netinet/igmp.h patch
- Copy linux/version.h in place before compiling glibc
* Fri May  9 2003 kukuk@suse.de
- Fix bits/stdio.h
- Fix lot of kernel headers to work in userspace
- Fix netinet/igmp.h
- Enable TLS on PPC
* Wed May  7 2003 kukuk@suse.de
- Update CVS snapshot
- Enable TLS on IA64
- Update to nptl 0.37
- Update kernel-headers to 2.5.69
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Apr 11 2003 aj@suse.de
- Do not build locales in parallel.
* Tue Apr  8 2003 kukuk@suse.de
- Disable TLS for PPC
* Mon Apr  7 2003 kukuk@suse.de
- Update CVS snapshot
* Sat Apr  5 2003 kukuk@suse.de
- Disable TLS for ia64
- Update to nptl 0.34
- Update to CVS snapshot
* Fri Apr  4 2003 kukuk@suse.de
- Remove libNoVersion from filelist on alpha
- Add nptl docu
* Fri Apr  4 2003 kukuk@suse.de
- Update to nptl 0.33
- Run ldconfig after installation
- Update to CVS snapshot
* Sat Mar 29 2003 kukuk@suse.de
- Update to CVS snapshot
- Add USAGI patches for kernel-headers
- Add nptl on i686
- Enable --with-tls
- Implement NI_NUMSERICSCOPE for getnameinfo
- Implement AI_V4MAPPED/AI_ALL for getaddrinfo
- Implement AI_ADDRCONFIG for getaddrinfo
- Add USAGI patch for kernel headers
* Mon Mar 24 2003 schwab@suse.de
- Sanitize <asm-ia64/pal.h>.
* Mon Mar 17 2003 aj@suse.de
- Fix tst-aio7 testcase and enable it again.
- Enable %%fs for x86-64.
- Install en_US.ISO-8859-15 for libstdc++.
- Fix bits/syscalls.h for x86-64.
* Thu Mar 13 2003 kukuk@suse.de
- Revert tcgetattr change [Bug #25173/#25174]
* Tue Mar  4 2003 aj@suse.de
- Fix <tgmath.h> lround/lrint functions.
* Sat Mar  1 2003 aj@suse.de
- Update to 2.3.2 release.
* Wed Feb 26 2003 kukuk@suse.de
- Update to current cvs snapshot (fixes OOo and mysql problems)
* Mon Feb 24 2003 kukuk@suse.de
- Disable aio7 test on s390(x), too.
* Mon Feb 24 2003 kukuk@suse.de
- Update to current cvs snapshot (post 2.3.2-pre1)
- Remove glibc-2.3-ppc32-textrel.patch, is included in CVS
- Remove libc23-ppc64-cvshead20021210.patch
* Thu Feb 20 2003 kukuk@suse.de
- Update to current cvs snapshot
- Remove glibc-2.3-ppc64-vfork-20030214.patch, seems to be
  included already.
* Wed Feb 19 2003 olh@suse.de
- add glibc-2.3-ppc32-textrel.patch
    glibc-2.3-ppc64-vfork-20030214.patch
* Fri Feb 14 2003 kukuk@suse.de
- Extend getent to print all IP addresses of one host
* Thu Feb 13 2003 kukuk@suse.de
- Update to current snapshot
* Wed Feb 12 2003 kukuk@suse.de
- Update to current snapshot (contains official fix for #23513)
* Tue Feb 11 2003 kukuk@suse.de
- Update to current snapshot
- Fix corruption of internal data in gethostbyname2 [Bug #23513]
* Sun Feb  9 2003 aj@suse.de
- Fix cancellation of system calls on x86-64.
* Sat Feb  8 2003 kukuk@suse.de
- Fix wrong logic in dynamic resolv.conf patch
* Fri Feb  7 2003 kukuk@suse.de
- Fix access of _res symbol in multithreaded programs
- Add "dynamic resolv.conf" patch to libnss_dns, too.
- Remove obsolete db2 manual pages
- Update to current snapshot (fixes [Bug #23363])
* Thu Feb  6 2003 kukuk@suse.de
- Update to current snapshot
- Use install-info for info pages
* Tue Feb  4 2003 schwab@suse.de
- Fix regexp parsing.
* Mon Feb  3 2003 meissner@suse.de
- Merged a unistd.h gcc3.3 compliance patch from Franz Sirl for
  ppc and ppc64 kernel headers.
* Fri Jan 31 2003 schwab@suse.de
- Fix building on s390[x].
* Fri Jan 31 2003 kukuk@suse.de
- Update to current glibc cvs
* Thu Jan 30 2003 aj@suse.de
- Fix one build problem on sparc.
- Fix asm-x86_64/mtrr.h.
* Wed Jan 29 2003 kukuk@suse.de
- Update to current glibc cvs
- Fix libm-ulps for x86-64 and ia64
* Thu Jan 23 2003 schwab@suse.de
- Fix use of DT_FINI_ARRAY.
- Temporarily disable tst-aio7 test on ia64.
* Tue Jan 14 2003 schwab@suse.de
- Fix ia64 for non-tls build.
* Tue Jan 14 2003 aj@suse.de
- Package libpthread_nonshared.a.
* Mon Jan 13 2003 kukuk@suse.de
- Add fixed version of x86-64-linuxthreads-disable-fs.diff
- Readd parts of libm-x86-64.diff
- Update to current cvs snapshot
- Add fix for errno compatibility
- Add s390(x) vfork fixes
* Sun Jan 12 2003 kukuk@suse.de
- Update to current cvs snapshot
* Fri Jan  3 2003 bg@suse.de
- removed obsolete patch for hppa
* Fri Dec 20 2002 kukuk@suse.de
- Update to current cvs snapshot
- Obsoletes glibc-2.3-setjmp-ppc64.diff
- Obsoletes build-alpha.diff
- Obsoletes libm-x86-64.diff
- Disable activate-spinlocks.diff temporary
- Disable x86-64-linuxthreads-disable-fs.diff (breaks compilation)
* Tue Dec 17 2002 olh@suse.de
- remove glibc-2.2.5-ppc64-bits-socket_h.diff
  add glibc-2.3-setjmp-ppc64.diff
  add libc23-ppc64-cvshead20021210.patch
  dont run configure in subshell, it can fail and rpm cant catch it
* Fri Dec 13 2002 schwab@suse.de
- Add more ia64 syscalls.
* Fri Dec  6 2002 olh@suse.de
- build also the locals parallel
  do not fail with parallel calculation on lowmem systems
* Tue Dec  3 2002 aj@suse.de
- Build parallel on x86-64.
- Activate fast spinlocks in malloc for x86 and x86-64.
- Integrate new math library from AMD for x86-64.
* Fri Nov 29 2002 bg@suse.de
- Fix build on hppa.
* Thu Nov 28 2002 aj@suse.de
- Fix build on alpha.
* Thu Nov 28 2002 aj@suse.de
- Update to CVS version from 2002-11-28.
- Do not use %%fs for threads for now on x86-64.
- Fix fnmatch bug with multibyte strings.
* Tue Nov 12 2002 bg@suse.de
- Updated hppa patches
* Thu Nov  7 2002 kukuk@suse.de
- getaddrinfo(): get host information for AF_INET and AF_INET6 only
  from the same service [Bug #21237]
* Thu Nov  7 2002 bg@suse.de
- Fix build of linuxthreads for hppa
* Tue Nov  5 2002 bg@suse.de
- Use current kernel-headers for parisc
- Add support for hppa
* Tue Nov  5 2002 kukuk@suse.de
- Update to current CVS snapshot
* Tue Oct 22 2002 schwab@suse.de
- Fix ia64 syscall numbers.
* Mon Oct 21 2002 schwab@suse.de
- Fix alignment in locale-archive.
* Mon Oct 21 2002 kukuk@suse.de
- Update to glibc 2.3.1 cvs 20021021
- Remove nss_dns6 patch
* Tue Oct 15 2002 kukuk@suse.de
- Update to glibc 2.3.1 cvs 20021015
* Wed Oct  2 2002 kukuk@suse.de
- Update to glibc 2.3 cvs 20021002
- Update crypt_blowfish to 0.4.4 (manual page fix, hppa fix)
* Wed Sep 25 2002 mls@suse.de
- build with -finline-limit=2000 on mips/armv4l
* Tue Sep 17 2002 schwab@suse.de
- Add new ia64 syscall numbers.
* Mon Sep 16 2002 meissner@suse.de
- Added AIO syscall numbers for ppc/ppc64, so libaio does not need them.
- Aligned powerpc bits/sem.h to be the same as the other 64bit
  archs, keeping the 32bit layout.
- Added the faster ppc32 memset.S from glibc HEAD on request of IBM.
* Thu Sep 12 2002 meissner@suse.de
- ppc/ppc64: added more biarch things to the SystemV IPC headers
  which are needed to get 64bit ipc / IPC_STAT to work.
* Mon Sep  9 2002 bk@suse.de
- s390x-biarch: use correct wordsize.h(move to main 32/64 directory)
- s390x: requires 64-bit kernel
* Mon Sep  9 2002 kukuk@suse.de
- Increase minimum value of MAXPACKET in libnss_dns, too
* Mon Sep  9 2002 uli@suse.de
- all architectures are created equal, but some are more equal
  than others; increased DB_FILE_ID_LEN in DB2 to 24 on x86-64,
  ia64, s390x and ppc64 to fit 64 bit __ino_t type
* Fri Sep  6 2002 mls@suse.de
- fix squeeze bug in db-1.85: set dirty flag after page modification
* Fri Sep  6 2002 kukuk@suse.de
- Increase minimum value of MAXPACKET
* Mon Sep  2 2002 kukuk@suse.de
- Fix asm header files for sparc/sparc64
* Fri Aug 30 2002 aj@suse.de
- Revert linuxthreads for x86-64 for now.
* Wed Aug 28 2002 aj@suse.de
- Add optimized math routines for x86-64.
* Tue Aug 27 2002 olh@suse.de
- BuildFlags="$(echo $RPM_OPT_FLAGS | sed 's#-mminimal-toc##')"
* Mon Aug 26 2002 olh@suse.de
- add ppc64_glibc_2.2.5_sunrpc-fix.patch
  * sysdeps/unix/sysv/linux/powerpc/bits/socket.h: New file that adds
  __powerpc64__ specific fields and adjust size/alignment for 64-bit.
* Fri Aug 23 2002 aj@suse.de
- Use floating stacks for x86-64.
- Add LICENSE file.
- Fix profiling code on x86-64.
- Add strcspn, strpbrk and strspn optimizations for x86-64.
- Fix makecontext for x86-64.
* Thu Aug 15 2002 aj@suse.de
- Use biarch headers already for building so that bits/syscalls.h is
  build correctly.
- Fix bits/syscalls.h for x86-64.
- Remove *xattr patches.
* Thu Aug  8 2002 kukuk@suse.de
- Update to current cvs (calloc variable overflow fixed)
- Apply fix for calloc fix
- Add *xattr system calls and error number
* Tue Aug  6 2002 kukuk@suse.de
- Update to current cvs (IPv6 fixes)
* Mon Aug  5 2002 aj@suse.de
- Implement *context functions for x86-64.
* Sat Aug  3 2002 kukuk@suse.de
- Update kernel-headers to version 2.4.19
- Add PreRequires "filesystem".
* Thu Aug  1 2002 bk@suse.de
- added s390-may2002.diff with some chunks from may2002 drop
- give make check a second chance on s390(x), but fail if not(race)
* Tue Jul 30 2002 kukuk@suse.de
- sunrpc/xdr_array.c: Check for variable overflow
- Ignore failed make check on s390(x)
* Tue Jul 30 2002 aj@suse.de
- Add optimisations for x86-64.
* Mon Jul 29 2002 kukuk@suse.de
- Don't allocate/free category name in setlocale() unnecessarily
  (for IBM Java [Bug #17065]).
* Tue Jul 23 2002 kukuk@suse.de
- Update to current glibc cvs (pread/pwrite fixes)
- Remove extra de.po, is in official tarball now.
* Sat Jul 20 2002 aj@suse.de
- Fix profiling for x86-64.
* Fri Jul 19 2002 meissner@suse.de
- Fixed the PPC64 patch, several superflous files removed.
- Reenabled make check for ppc64.
* Wed Jul 17 2002 kukuk@suse.de
- Update to current glibc cvs
- Fix kernel headers for s390/s390x
- Move some binaries/shell scripts and manual pages to the
  correct subpackage
* Tue Jul 16 2002 meissner@suse.de
- Merged latest PowerPC patch from IBM.
  * Lots of ppc64 related fixes.
  * Start of biarch support.
  * Changed struct stat in 64bit ABI.
* Fri Jul 12 2002 aj@suse.de
- Add biarch patch for s390 and s390x.
* Mon Jul  8 2002 aj@suse.de
- Add some optimized x86-64 math routines and a fixed lgammal
  implementation.
- Testsuite on x86-64 should pass now.
- Run ldconfig in postinstall.
- Fix memleak in catgets.
* Sat Jul  6 2002 kukuk@suse.de
- Fix typo in create_biarch_asm.sh (asm-sparc path)
* Thu Jul  4 2002 kukuk@suse.de
- Fix typo in manpages/Makefile
- Fix filelist (on some archs ld-linux.so.2 was missing)
* Thu Jul  4 2002 kukuk@suse.de
- Revert mktime patch (check for year < 70)
- Replace ifarch i386 with ix86
- Add patch for arm
- Include pt_chown again
* Wed Jul  3 2002 kukuk@suse.de
- Add more new manual pages
- Fix spec file (renaming of ld-*, creating of include/asm header
  files)
- Update to current CVS version
- Fix kernel-headers for x86-64 (don't overwrite patched version)
- Rename Equador -> Ecuador [Bug #16648]
- Add hint about security problem of host caching with nscd to
  config file.
* Tue Jun 25 2002 aj@suse.de
- Fix dl-machine.h for x86-64 to compile with new binutils.
- Fix mtrr.h header for x86-64.
- Do not package pt_chown.
* Tue Jun 18 2002 sf@suse.de
- reverted changes from Tue Jun 11 10:04:55 CEST 2002
  (took the kernel-headers from before, readded patch9)
- add new archive with kernel-headers for x86_64
- add autofs patch
* Mon Jun 17 2002 bk@suse.de
- remove s390* from the list of archs that ignore check fail
* Thu Jun 13 2002 uli@suse.de
- fixed typos in spec
* Thu Jun 13 2002 schwab@suse.de
- Fix ssize_t and __ipc_pid_t for ppc64.
* Wed Jun 12 2002 uli@suse.de
- fix errlist.c for ARM as well
* Tue Jun 11 2002 sf@suse.de
- made new kernel-header archive from kernel-source
- added asm-ppc64 to kernel-headers
- removed patch9 as it is obsoleted by the new kernel-headers
* Fri Jun  7 2002 olh@suse.de
- update asm-ppc64/ioctls.h, missing TIOCGDEV
* Thu Jun  6 2002 olh@suse.de
- fix glibc-ppc64 patch
* Thu Jun  6 2002 olh@suse.de
- update ppc64_glibc_ldconfig.diff
* Thu Jun  6 2002 ke@suse.de
- Update de.po from
  http://www.iro.umontreal.ca/contrib/po/teams/PO/de/libc-2.2.5.de.po.
- Use only translated entries to make the testsuite happy; call
  msgattrib on de.po and hu.po [# 16438].
* Mon Jun  3 2002 aj@suse.de
- Clean up generation of asm includes for bi-arch systems.
- Enable profiling for x86-64.
* Mon Jun  3 2002 kukuk@suse.de
- Add fix for weak declaration "_old_sys_nerr"
- Remove already disabled alpha patch
- Update to current CVS
* Sat Jun  1 2002 olh@suse.de
- fix stat for real, wrong size for st_nlink
* Wed May 29 2002 olh@suse.de
- add ppc64_glibc_2.2.5-types.diff, fixes stat()
* Wed May 29 2002 olh@suse.de
- add ppc64_glibc_ldconfig.diff for elf32/elf64 coexistance
* Thu May 23 2002 aj@suse.de
- Rename __thread to fix problems with GCC 3.2.
* Mon May 20 2002 olh@suse.de
- add ppc64 kernel headers
  add create_ppc_asm.sh
  update ppc64 patch, use /lib64/ld64.so.1
  move generic syscalls.list to ppc64/32
  set/getrlimit GLIBC2.0 is ppc32 only
  use parallel make on ppc and ppc64
  do not chroot as user
  cleanup nested ifarch for dynamic linker
* Wed May 15 2002 aj@suse.de
- Fix building of linuxthreads with current GCC.
* Mon May 13 2002 olh@suse.de
- fix ppc64 RTLDLIST ld64.so rewrite
* Sat May 11 2002 schwab@suse.de
- Add div/mod compatibility functions for ia64.
* Fri May 10 2002 olh@suse.de
- add ppc64 support
* Thu May  9 2002 aj@suse.de
- Add sys/io.h for x86-64.
* Mon May  6 2002 ihno@suse.de
- corrected memory calculation for parallel build
* Fri May  3 2002 kukuk@suse.de
- Add fix to compile math.h on SPARC with g++
* Thu May  2 2002 kukuk@suse.de
- Update to current CVS 2.2 branch
- Add x86-64 fix for crti.o and /usr/lib64 with libpthread
* Fri Apr 26 2002 kukuk@suse.de
- define sqrtl alias for PowerPC
* Mon Apr 22 2002 aj@suse.de
- Fix vfork for x86-64.
- Fix handling of ld.so.cache for x86-64.
* Thu Apr 18 2002 aj@suse.de
- Allow testsuite to fail for x86-64.
- Add ULPs for x86-64.
* Wed Apr 17 2002 kukuk@suse.de
- Update to current snapshot (mktime and dl fixes)
- Update hu.po
- Do not build a profiled glibc for x86-64
* Fri Apr 12 2002 kukuk@suse.de
- Update to current snapshot (fix SPARC compile)
- Revert do-lookup.h patch on Alpha (does not work here)
* Wed Apr 10 2002 aj@suse.de
- Fix linuxthreads for x86-64.
* Wed Apr 10 2002 aj@suse.de
- Add x86-64.diff to fix glob64.
* Wed Apr 10 2002 kukuk@suse.de
- Update kernel-headers to 2.4.19pre4 (with x86-64 support)
- Update glibc to current cvs snapshot
- Allow old currencies (before EUR)
* Tue Apr  2 2002 aj@suse.de
- Update ULPs.
* Thu Mar 21 2002 kukuk@suse.de
- Create html pages after installation of info pages [Bug #15283]
* Tue Mar 12 2002 kukuk@suse.de
- Add db1 fix if blocksize is not ^2
* Sat Mar  2 2002 kukuk@suse.de
- Add fix for format string bug
* Sat Mar  2 2002 kukuk@suse.de
- Fix return value of nice wrapper
* Fri Mar  1 2002 kukuk@suse.de
- Add fix for corrupt ut_line
- Add fix for current gcc 3.1
- Add patch for nice return values
* Thu Feb 28 2002 kukuk@suse.de
- Add fix for rtime, swscanf and ia64
* Mon Feb 18 2002 kukuk@suse.de
- When a dlopened module references a weak symbol from another
  dlopened module (loaded with RTLD_GLOBAL) no dependency was
  generated for this fact, so the second module was unloaded even
  if the first one was still around.
* Sun Feb 17 2002 kukuk@suse.de
- Add pthread/signal bugfix [Bug #13280]
- Fix directory file list (don't include /usr/include)
* Thu Feb 14 2002 kukuk@suse.de
- Use defattr in spec file to avoid problems with not existing
  UIDs and rpm.
* Thu Feb 14 2002 aj@suse.de
- Update ULPs for GCC 3.1.
* Wed Feb 13 2002 kukuk@suse.de
- Apply db1 patch from mls@suse.de to fix rpm problems
* Tue Feb 12 2002 ro@suse.de
- fix owner/group for kernel headers
* Mon Feb 11 2002 kukuk@suse.de
- Add another solution for the glob problem
* Thu Feb  7 2002 kukuk@suse.de
- Add fix for glob (glob should not call globfree)
- Add fix for innetgr
* Wed Feb  6 2002 kukuk@suse.de
- Use correct BuildRoot
* Wed Feb  6 2002 kukuk@suse.de
- Update hu.po
* Wed Feb  6 2002 kukuk@suse.de
- Set LC_CTYPE for error messages in localedef [Bug #12878]
* Mon Feb  4 2002 kukuk@suse.de
- Add fixes from CVS: dynamic loader, readv and writev seg.fault
  and various architecture fixes for alpha and mips
- Don't compile with -g on Alpha
- Add fix for possible endless loop fix
* Fri Feb  1 2002 bk@suse.de
- merged s390x lib64 patch and spec file changes
* Wed Jan 23 2002 kukuk@suse.de
- Split glibc into glibc and glibc-locale
- Create more UTF8 locale
* Mon Jan 21 2002 kukuk@suse.de
- Update to official glibc 2.2.5
* Wed Jan 16 2002 kukuk@suse.de
- Remove /var/adm/setup/setup.timeconfig
* Wed Jan 16 2002 kukuk@suse.de
- Apply S390 fix
* Wed Jan  9 2002 kukuk@suse.de
- Update to glibc 2.2.5pre1
* Tue Jan  8 2002 egmont@suselinux.hu
- Added partial Hungarian translation
* Tue Jan  8 2002 kukuk@suse.de
- Add patch to pass math tests with gcc 3.x
- Update to current CVS version
* Thu Jan  3 2002 kukuk@suse.de
- Update kernel header files to 2.4.17
* Tue Jan  1 2002 kukuk@suse.de
- Update current CVS version, add final fixes for LSB test suite
* Tue Dec 18 2001 poeml@suse.de
- Install ja_JP.SJIS locale.
* Sat Dec 15 2001 schwab@suse.de
- Fix missing declaration of md5_uintptr.
* Fri Dec 14 2001 kukuk@suse.de
- Update to correct CVS branch
* Thu Dec 13 2001 kukuk@suse.de
- Update to current CVS
- Increase PATH_MAX to 4096 (including the leading zero)
- Clear pointer if asprintf fails
- pthread_key_delete should not contact thread manager before it
  is created.
* Tue Dec 11 2001 kukuk@suse.de
- Fix prelink patch
* Tue Dec 11 2001 kukuk@suse.de
- Add fixes for LSB.os test suite (ftw, grantpt and ftok)
- Update to current CVS
- Add prelink patch
* Fri Dec  7 2001 kukuk@suse.de
- Merge with current CVS
- Add blowfish crypt
* Fri Nov 23 2001 uli@suse.de
- added armv4l arch to spec
- added arm kernel headers
- added trivial fix for dl-machine.h from CVS (see arm.dif)
* Thu Nov 15 2001 adrian@suse.de
- add mips architecture to spec file
- apply further mips fixes for ld
- activate %%clean again
* Sun Nov 11 2001 kukuk@suse.de
- Fix lost permissions of shell script on SPARC
* Thu Nov  8 2001 kukuk@suse.de
- Add 32bit UID fixes
* Thu Nov  8 2001 kukuk@suse.de
- More fixes for asm-ia64 header files
* Thu Nov  8 2001 kukuk@suse.de
- Fix asm-i386/processor.h (don't align struct)
- Fix asm-ia64/bitops.h (define CMPXCHG_BUGCHECK)
- Correct version number in version.h
* Wed Nov  7 2001 uli@suse.de
- fixed sys/io.h, sysmacros.h for icc
* Tue Nov  6 2001 kukuk@suse.de
- Update kernel-headers to 2.4.14
* Thu Nov  1 2001 kukuk@suse.de
- Use again old rules to generate html files
* Sun Oct 21 2001 schwab@suse.de
- Fix inttypes.h for C++.
* Fri Oct 19 2001 aj@suse.de
- Fix typo in inttypes.h that presents compilation by non-GCC compilers.
* Tue Oct 16 2001 aj@suse.de
- Update elf.h to include x86-64 defines since those are needed
  by some other tools.
* Fri Sep 28 2001 schwab@suse.de
- Readd patch from 2001-09-10 with corrections.
- Add compatibility patch for GCC 3.  This allows to build glibc
  with GCC 3.
- Require that make check succeeds on ia64.
* Thu Sep 13 2001 aj@suse.de
- Add a better version of the threads-fork patch that fixes some
  more places where interrupts can occur and does this a bit cleaner.
* Tue Sep 11 2001 aj@suse.de
- Remove patch from 2001-09-10 since it breaks the dynamic linker.
* Tue Sep 11 2001 aj@suse.de
- Fix bug in linuxthreads where manager and threads could
  get out of synch due to an interrupted read call.
* Mon Sep 10 2001 schwab@suse.de
- Fix handling of dependent dynamic objects for dlopen/dlclose.
* Sat Sep  8 2001 kukuk@suse.de
- Don't create gconv cache (else iconv --list seg.faults)
* Tue Aug 28 2001 aj@suse.de
- Improve dynamic linker to relocate dynamic objects faster.  This
  implies a small cache for symbol lookups and handling the ld -z combreloc
  feature if binaries are linked this way.
* Fri Aug 24 2001 kukuk@suse.de
- Add fix for handling of %%l[] in vfscanf
- ldconfig removes stale links now
- Remove susehelp config files, now in susehelp itself
* Wed Aug 22 2001 aj@suse.de
- Update s390 patch from IBM.
* Fri Aug 17 2001 kukuk@suse.de
- Adjust dns6 patch for 2.2.4
- Fix spec file (include lost libnss_dns6.so)
- Fix versionnumber in version.h [Bug #9759]
- Update kernel-header to 2.4.9
* Thu Aug 16 2001 aj@suse.de
- Update to 2.2.4 final.  Add s390-ucontext patch.
* Fri Aug 10 2001 aj@suse.de
- Update to current glibc version.  Do not use the hardlink program
  for compatification since localedef will do this itself now.
  Create gconv cache.
* Wed Aug  1 2001 aj@suse.de
- Add patch for zic to create copy of the timezone instead
  of a symbolic link so that the file exists even if /usr is not
  mounted.
  Use i486 instead of i386 as default architecture for i386.
* Sat Jul 28 2001 kukuk@suse.de
- Fix problem with linux/spinlock.h
* Fri Jul 27 2001 kukuk@suse.de
- Update kernel-header files to 2.4.7
* Thu Jul 26 2001 froh@suse.de
- add fix for failing tst-setcontext on s390
* Wed Jul 25 2001 aj@suse.de
- Add patch to fix loading of dynamic libs in static programs for PPC.
* Fri Jul 20 2001 kukuk@suse.de
- Update to current CVS snapshot
- Disable tst-regex and test-lfs
* Fri Jul  6 2001 kukuk@suse.de
- Add da_DK@euro and da_DK.UTF-8
* Thu Jul  5 2001 kukuk@suse.de
- Update to current CVS snapshot
- Remove obsolete cvs patch
- Fix DNS/IPv6 patch
- Hardlink equal locale files
* Fri Jun 22 2001 olh@suse.de
- add glibc-2.2.3-ppc_dlmachine.diff to fix binutils make check
* Tue Jun 19 2001 aj@suse.de
- Fix profiling on PowerPC.
* Tue Jun 19 2001 bk@suse.de
- added s390x support to spec file
* Fri Jun 15 2001 schwab@suse.de
- Fixup asm-ia64/atomic.h for user-space inclusion.
* Tue Jun 12 2001 aj@suse.de
- Fix testsuite for sparc.
* Mon Jun 11 2001 aj@suse.de
- Fix testsuite for powerpc and S390, build again on alpha.
* Tue May 22 2001 kukuk@suse.de
- Update to current CVS snapshot
- Rmove support for PF_LOCAL from getaddrinfo [Bug #8469]
* Sun May 13 2001 kukuk@suse.de
- Don't use absolute paths in pre-install-section
* Fri May  4 2001 kukuk@suse.de
- Add special version.h which fails on compiling kernel modules
* Sat Apr 28 2001 kukuk@suse.de
- Update to glibc 2.2.3, kernel-headers-2.4.4
* Tue Apr 24 2001 schwab@suse.de
- Fix feenableexcept on ia64.
* Tue Apr 24 2001 aj@suse.de
- Install some more UTF-8 locales, fix tr_TR locale.
* Thu Apr 12 2001 kukuk@suse.de
- Include our own texi2html
* Wed Apr 11 2001 kukuk@suse.de
- Add fixes from SuSE kernel header files
- Add patch to reload /etc/resolv.conf if there was changes
- Add glibc.conf for susehelp (glibc-html pages)
* Mon Apr  9 2001 schwab@suse.de
- Fix ld.so for kernel 2.4.3 on ia64.
* Thu Apr  5 2001 kukuk@suse.de
- Add more fixes from CVS
* Tue Apr  3 2001 kukuk@suse.de
- Fix isdn header files from kernel-headers
* Fri Mar 30 2001 kukuk@suse.de
- Update kernel header files to 2.4.3
* Fri Mar 30 2001 kukuk@suse.de
- Merge s390 patches
- Fix rcmd_af() (allow PF_UNSPEC)
* Fri Mar 30 2001 aj@suse.de
- Add some small fixes, fix spec file for removal of man-pages.
* Thu Mar 29 2001 kukuk@suse.de
- Don't provide kernel_headers any longer
- Remove some man-pages which are now official in the man-pages
  package
* Thu Mar 29 2001 aj@suse.de
- Fix shmfs recognition.
* Wed Mar 28 2001 ro@suse.de
- added db-splitmask fix from mls (hopefully work around bug in db1)
* Wed Mar 28 2001 aj@suse.de
- Fix s390 to not generate wrong relocations, work around compiler
  error.
* Wed Mar 21 2001 kukuk@suse.de
- glibc-devel obsoletes and provides linclude
* Tue Mar 20 2001 kukuk@suse.de
- Add strtok and other fixes from CVS
- Add yp_all fix
* Tue Mar 13 2001 kukuk@suse.de
- Add more s390 string.h fixes
* Mon Mar 12 2001 aj@suse.de
- Add fixes for s390, don't run testsuite on s390 for now.
* Fri Mar  9 2001 kukuk@suse.de
- Fix linux/init.h header file
* Fri Mar  9 2001 aj@suse.de
- Handle new EM_S390 value.
* Fri Mar  9 2001 kukuk@suse.de
- kernel-heaer fixes to build on Alpha
* Thu Mar  8 2001 ro@suse.de
- update kernel-headers to 2.4.2
* Thu Mar  8 2001 ro@suse.de
- kernel-header fixes to build on s390
* Thu Feb 22 2001 schwab@suse.de
- More kernel header fixes for IA64.
* Tue Feb 20 2001 kukuk@suse.de
- Remove optimisation not supported on all plattforms
* Mon Feb 19 2001 kukuk@suse.de
- Fix Optimization of glibc build
- Add Optimization for alphaev6 and sparcv9
* Sat Feb 17 2001 kukuk@suse.de
- Update to glibc 2.2.2 from CVS
* Thu Feb 15 2001 kukuk@suse.de
- kernel header fixes for SPARC and IA64
* Tue Feb 13 2001 kukuk@suse.de
- Make optimization for i686 work
- Add manual page for ldd
* Mon Feb 12 2001 kukuk@suse.de
- Fix more kernel headers
* Thu Feb  8 2001 kukuk@suse.de
- Fix more kernel-headers
* Wed Feb  7 2001 kukuk@suse.de
- Delete links in pre install section for glibc-devel
* Wed Feb  7 2001 kukuk@suse.de
- Fix kernel-header includes
* Tue Feb  6 2001 kukuk@suse.de
- Fix creating of /usr/include/asm on SPARC
- Add more CVS patches
* Mon Feb  5 2001 kukuk@suse.de
- Add some patches from CVS
- Include our own kernel header files
* Mon Jan 22 2001 aj@suse.de
- Add elf patch to fix problems on ia64 and ppc with _dl_pagesize.
* Mon Jan 22 2001 aj@suse.de
- Fix mmap64 on powerpc.
* Tue Jan 16 2001 aj@suse.de
- Fix sunrpc-udp.diff, add mman.h fix for powerpc.
* Wed Jan 10 2001 aj@suse.de
- Add sunrpc-udp.diff to fix UDP timeouts with Linux 2.4 kernel.
* Tue Jan  9 2001 aj@suse.de
- Add glibc-2.2.secure.diff to close some security holes.
* Wed Jan  3 2001 schwab@suse.de
- Fix strtol and friends on 64 bit platforms.
- Use 8192 as default pagesize on ia64.
- Scan AUX vector also in statically linked programs.
* Wed Jan  3 2001 aj@suse.de
- Build some UTF-8 locales using a patch from Markus Kuhn.
* Wed Dec 13 2000 aj@suse.de
- Add compatibility patch for IPv6 and Linux 2.2.
* Wed Dec 13 2000 schwab@suse.de
- Update ia64 patch.
* Sat Dec  9 2000 kukuk@suse.de
- Fix resolver bug
* Fri Dec  1 2000 kukuk@suse.de
- Add bug fixes for setlocale and strncat
- strip gconv modules
* Fri Nov 24 2000 kukuk@suse.de
- Fix typo in spec file
* Thu Nov 23 2000 kukuk@suse.de
- Add hack for POWER3
* Wed Nov 22 2000 kukuk@suse.de
- Add strncat bugfix for S/390
* Tue Nov 21 2000 kukuk@suse.de
- Don't bulid 32bit compat packages
* Mon Nov 20 2000 schwab@suse.de
- Remove use of getpagesize syscall on ia64.
- Follow DT_INIT/DT_FINI change in compiler.
* Sun Nov 19 2000 kukuk@suse.de
- Minor specfile fixes
* Thu Nov 16 2000 kukuk@suse.de
- Add lot of more bug fixes
* Tue Nov 14 2000 kukuk@suse.de
- Add bugfix for static linked binaries/ld.so.cache from aj@suse.de
* Mon Nov 13 2000 aj@suse.de
- Fix noversion.diff and spec file.
* Sat Nov 11 2000 kukuk@suse.de
- Fix nssv1 on PowerPC
- no libNoVersion on SPARC
* Fri Nov 10 2000 kukuk@suse.de
- Disable make check on PowerPC and Alpha
* Fri Nov 10 2000 kukuk@suse.de
- Update to final glibc 2.2
* Fri Nov  3 2000 kukuk@suse.de
- Update to glibc-2.2-20001103 (glibc-2.1.97)
- Don't install libNoVersion on PowerPC
- Rename nssv1 -> glibc-nssv1
- Rename libd -> glibc-profile, move libg.a to libc
- Rename libcinfo -> glibc-info
- Rename libchtml -> glibc-html
- Rename localedb -> glibc-i18ndata
- Rename libc -> glibc-devel
- Rename shlibs -> glibc
* Sat Oct 28 2000 kukuk@suse.de
- Update to glibc-2.2-20001028
- Enable more checks
* Fri Oct 27 2000 aj@suse.de
- Fix NoVersion patch
* Wed Oct 25 2000 kukuk@suse.de
- Update to glibc-2.2-20001025
* Sun Oct 22 2000 kukuk@suse.de
- Update to glibc 2.2-20001021
- Update glibc-db to 2.1.95
- Update ia64 patch
* Fri Oct 20 2000 kukuk@suse.de
- Update to glibc 2.2-20001020
- Add s390 spec file changes
* Tue Oct 10 2000 schwab@suse.de
- Update to glibc 2.2-20001009.
- Fix TRAMPOLINE_TEMPLATE for ia64.
* Sun Oct  1 2000 schwab@suse.de
- Export more ia64 specific symbols.
* Tue Sep 26 2000 kukuk@suse.de
- Update to glibc 2.2-20000926
* Mon Sep 25 2000 kukuk@suse.de
- Update to glibc 2.2-20000925 snapshot
* Thu Sep 14 2000 schwab@suse.de
- Update ia64 patch.
* Fri Sep  8 2000 bk@suse.de
- added glibc-2.1.3-db2-s390.tar.gz from developerworks (db2 fix)
* Wed Sep  6 2000 fober@suse.de
- merge s390-7.0 with STABLE:
  - upgraded to glibc-linuxthreads-2.1.3.1-s390.diff from 2.1.3
  - added new changes from IBM s390 codedrop
  - removed glibc-dlopen-2.1.3-s390.diff which is
    incorporated in glibc-linuxthreads-2.1.3.1-s390.diff now
* Tue Sep  5 2000 kukuk@suse.de
- Add glibc-2.1.security.dif
* Fri Sep  1 2000 olh@suse.de
- add glibc-2.1-ppc_lfs.dif, enables (hopefully) lfs on ppc
* Wed Aug 30 2000 olh@suse.de
- remove sysdeps/powerpc/memset.S on ppc for POWER3
* Mon Aug 28 2000 olh@suse.de
- add glibc-2.1.sgi_fam.dif
- remove sysdeps/rs6000/memcopy.h on ppc for POWER3
* Mon Aug 21 2000 garloff@suse.de
- Fix race on cond_wait WRT owner of mutex (from olh@suse.de)
* Tue Jul 25 2000 kukuk@suse.de
- Add mmap fix for PowerPC
* Tue Jul 11 2000 kukuk@suse.de
- Remove "mutex is owned by current thread" bugfix for IBMs jdk
* Mon Jun 26 2000 schwab@suse.de
- Update ia64 patch.
* Tue Jun 20 2000 kukuk@suse.de
- Move html docu in extra package
- Update ia64 patch
* Wed May 31 2000 kukuk@suse.de
- Remove LICENSE file, it's the same as COPYING.LIB
- Add libc docu as html
* Sun May 28 2000 kukuk@suse.de
- Fix ldconfig on PPC and IA64
* Sat May 27 2000 kukuk@suse.de
- Merge new ldconfig fixes
* Fri May 26 2000 kukuk@suse.de
- Update ia64 patch
* Fri May 26 2000 kukuk@suse.de
- Fix (f)truncate64 and xdr_uint8_t
* Wed May 24 2000 kukuk@suse.de
- Fix ldconfig.8 manual page
* Thu May 18 2000 bk@suse.de
- added s390 dlopen fix
* Tue May 16 2000 bk@suse.de
- updated s390 patches to match IBM_codedrop_2000_05_15
* Fri May 12 2000 kukuk@suse.de
- Fix netinet/in.h IPv6 compare
* Fri May 12 2000 schwab@suse.de
- Update ia64 patches.
* Fri May 12 2000 kukuk@suse.de
- Don't apply LFS patch
* Tue May  9 2000 kukuk@suse.de
- Add LFS patches
* Mon May  8 2000 kukuk@suse.de
- Add lot of bug fixes from CVS
* Tue Apr 25 2000 kukuk@suse.de
- Fix nscd/getgrnam bug
* Thu Apr 20 2000 kukuk@suse.de
- Remove /var/mail -> /var/spool/mail patch
- Update nscd.conf.5 manual page
* Wed Apr 12 2000 kukuk@suse.de
- Add nscd patch from Chris Wing
* Wed Apr 12 2000 kukuk@suse.de
- Add ldconfig fix from aj@suse.de
* Wed Apr 12 2000 schwab@suse.de
- More ia64 patches.
- Use libc.so.0, libm.so.0, ld-linux-ia64.so.1 on ia64.
* Mon Apr 10 2000 kukuk@suse.de
- Support asm-sparc64 and asm-sparc on SPARC
* Mon Apr 10 2000 kukuk@suse.de
- Create /etc/ld.so.cache always with permissions 0644
- Update ia64 patches
* Thu Apr  6 2000 schwab@suse.de
- Fix dynamic linker bug in ia64.
- Add ia64 spinlocks for db2.
* Tue Apr  4 2000 schwab@suse.de
- New IA64 patches.
- Fix ldconfig -p.
* Mon Apr  3 2000 bk@suse.de
- s390 team added s390 patches
* Wed Mar 22 2000 kukuk@suse.de
- Fix last SPARC patch
* Tue Mar 21 2000 kukuk@suse.de
- Add SPARC patches
- Add IA64 patches
* Wed Mar 15 2000 kukuk@suse.de
- Remove personality call (problematic on Alpha)
- Fix typo in localeconv
- alpha/ioperm.c> Add entry for "Nautilus".
* Tue Mar  7 2000 kukuk@suse.de
- Add locale SIGSEGV fix
- Fix getdate bug
* Fri Feb 25 2000 kukuk@suse.de
- Update to final glibc 2.1.3 + fix for bigendian machines
* Thu Feb 24 2000 kukuk@suse.de
- Update to current glibc cvs snapshot
- Add libnss_dns6.so.2, which makes IPv4 and IPv6 lookups.
  Old libnss_dns.so.2 will only make IPv4 lookups.
* Tue Feb 22 2000 kukuk@suse.de
- Update to current glibc cvs snapshot (2.1.3pre4)
* Sat Feb  5 2000 kukuk@suse.de
- Add missing defines for SPARC bits/termios.h
* Thu Feb  3 2000 kukuk@suse.de
- Add regex patch from Andreas Schwab
* Wed Feb  2 2000 kukuk@suse.de
- Add ldconfig fix
- Update to current glibc cvs snapshot
- Fix sys/io.h on Intel (C++)
* Mon Jan 24 2000 kukuk@suse.de
- Fix duplicate setrlimit
* Mon Jan 24 2000 kukuk@suse.de
- Update to current glibc cvs snapshot
* Wed Jan 19 2000 kukuk@suse.de
- Update to current glibc cvs snapshot
* Sat Jan 15 2000 ro@suse.de
-fixed ppc db2-patch
* Fri Jan 14 2000 kukuk@suse.de
- Add patches for Intel and PPC
* Thu Jan 13 2000 kukuk@suse.de
- Add patch for SPARC
* Thu Jan 13 2000 kukuk@suse.de
- Move info pages to /usr/share/info
* Mon Jan 10 2000 kukuk@suse.de
- Add ipv6 patches for getent
* Mon Jan 10 2000 kukuk@suse.de
- Move manual pages for applications and config files into
  shlibs package
- Update to current glibc 2.1.3 snapshot
* Fri Dec 17 1999 kukuk@suse.de
- Add new ldconfig patches
- Add aio patch
- Add fix for bits/string2.h
* Wed Dec 15 1999 kukuk@suse.de
- add ldconfig.8
* Wed Dec 15 1999 kukuk@suse.de
- Update to current glibc 2.1.3 snapshot
- Fix get/setrlimit problems
* Thu Dec  9 1999 kukuk@suse.de
- Update to current glibc 2.1.3 snapshot
- Add new ldconfig
* Sun Dec  5 1999 kukuk@suse.de
- Disable make check for SPARC (kernel bug)
- Add setrlimit patches
- Update to current glibc 2.1.3 snapshot
* Fri Nov 26 1999 kukuk@suse.de
- Update to current glibc 2.1.3 snapshot.
* Tue Oct 26 1999 kukuk@suse.de
- Add fix for correct accounting of needed bytes (gethnamaddr.c)
- Remove not exported, public names from internal md5 functions
* Mon Oct 25 1999 kukuk@suse.de
- Add fix for missing nexttowardl aliase
* Tue Oct 19 1999 kukuk@suse.de
- Add security fix for iruserok
* Sat Oct 16 1999 kukuk@suse.de
- Build libNoVersion.so.1 on every platform
* Mon Oct 11 1999 kukuk@suse.de
- Add linuxthreads/signals.c fix from Andreas Schwab
- Remove dangling symlink (Bug #544)
- Add more bug fixes
* Fri Oct  8 1999 kukuk@suse.de
- Add timezone update
* Fri Oct  8 1999 kukuk@suse.de
- Add NIS+ shadow parser fix
* Thu Oct  7 1999 kukuk@suse.de
- Update to official glibc 2.1.2, add important fixes
- Update nscd, add manual pages for it
* Mon Sep 20 1999 ro@suse.de
- libc: added requires kernel_headers
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Sep  6 1999 kukuk@suse.de
- Update to current glibc 2.1.2 cvs snapshot
- Remove use auf automake in spec file
* Fri Sep  3 1999 kukuk@suse.de
- Update to current glibc 2.1.2 cvs snapshot
- Use RPM macros for configure
* Wed Aug 25 1999 kukuk@suse.de
- Update to current glibc 2.1.2 cvs snapshot
* Thu Aug 19 1999 kukuk@suse.de
- Add PowerPC patches from Uli Hecht
- Cleanup of SPEC file
- Create a profiling version
* Sat Aug 14 1999 kukuk@suse.de
- disable nscd hosts caching by default
- Apply patch from HJL for broken gethostbyname_r in libnss_dns
* Fri Jul 16 1999 kukuk@suse.de
- Add header fix for autoconf/g++
- Move pt_chown and gconv modules from libc to shlibs
* Wed Jul 14 1999 kukuk@suse.de
- Remove /etc/localtime from filelist
* Mon Jul 12 1999 kukuk@suse.de
- Add more bug fixes from cvs
- Add ld.so bug fix from Andreas Schwab
* Thu Jul  8 1999 kukuk@suse.de
- configure for i386-unknown-linux
* Wed Jul  7 1999 kukuk@suse.de
- Remove alpha patch, it's now in glibc 2.1.2 cvs
- Add more bug fixes from cvs
- Remove malloc patch (breaks StarOffice)
* Tue Jul  6 1999 kukuk@suse.de
- Add openpty patch from Andreas Schwab
  (openpty now works if /dev/pts is not mounted)
* Fri Jul  2 1999 kukuk@suse.de
- Remove warning von zic about symlinks.
* Mon Jun 28 1999 kukuk@suse.de
- Remove ndbm links, now in gdbm
* Fri Jun 25 1999 kukuk@suse.de
- Add a lot of more fixes
- Add nscd fixes and enable nscd on alpha
* Mon Jun 14 1999 kukuk@suse.de
- Add nss_dns and fget* fixes.
- Add nscd patches for NIS+
* Thu Jun 10 1999 kukuk@suse.de
- Fix daemon() for MT programs
- Add libio fixes
* Fri May 28 1999 kukuk@suse.de
- Add fix for docu
- Disable nscd for alpha again
* Wed May 26 1999 kukuk@suse.de
- Update to version 2.1.1
* Mon May 17 1999 kukuk@suse.de
- Update to snapshot from 16.5.1999
- Add manpages
- Add __setfpucw to libNoVersion (intel)
- Add COPYING and COPYING.LIB
* Fri May  7 1999 kukuk@suse.de
- Update to snapshot from 6.5.1999
- Add NoVersion patches from RedHat for miscompiled glibc 2.0 apps
- Add patch for Alpha RX164
- Add workaround for nscd on Alpha
* Wed Apr 28 1999 kukuk@suse.de
- Remove latest fnmatch patches from Uli Drepper
* Tue Apr 27 1999 kukuk@suse.de
- update to cvs version of Apr 26 1999
- fix pmap_set/pmap_unset for DHCP clients
- Rename libdb1.so.2[.1] to libdb.so.2[.1] since we don't create
  the symbolic links.
* Tue Apr 20 1999 kukuk@suse.de
- update to cvs version of Apr 20 1999
- remove sunrpc.diff
- fix nssv1 package
- only include nscd on intel
- install /etc/nscd.conf
* Mon Apr 12 1999 kukuk@suse.de
- update to cvs version of Apr 11 1999
- Fix paths in paths.h
- install linuxthreads man pages and documentation
- Add sunrpc patch for Alpha and security fixes
- added links for el_GR and ru_RU.KOI8-R in usr/share/locale
* Wed Mar 31 1999 bs@suse.de
- don't use lx_hack for build
* Tue Mar 16 1999 ro@suse.de
- libc.texinfo: changed to build with stable texinfo version
* Mon Mar 15 1999 ro@suse.de
- update to 2.1.1 (cvs of Mar 15 1999)
- update nssv1 to 2.0.2
* Sat Feb 20 1999 ro@suse.de
- fixed specfile (lddlibc4 not built on alpha)
* Sat Feb 20 1999 ro@suse.de
- fixed specfile ...
* Sat Feb 20 1999 ro@suse.de
- added automake to neededforbuild
* Sat Feb 20 1999 ro@suse.de
- added nss-v1 modules (to keep old rpm happy with file owners)
* Fri Feb 19 1999 ro@suse.de
- update to cvs-version of 1999/02/18
* Fri Sep 25 1998 ro@suse.de
- fixed specfile
* Fri Sep 25 1998 ro@suse.de
- update: use cvs-version of 980925
  edited db/Makefile to ignore messed up target-dependency
* Mon Sep 21 1998 ro@suse.de
- update: use cvs-version of 980921
* Mon Sep 14 1998 ro@suse.de
- update: use today's cvs-version
* Wed Sep  2 1998 ro@suse.de
- build for 586 since egcs generates code for 686 that does NOT run
  on 586 !!! (eg strtok)
* Fri Aug 21 1998 ro@suse.de
- updated to cvs-version 20.8.98
  added gettext as neededforbuild (so configure shuts up)
  glibc-linuxthreads is contained in main archive now
* Tue Jun 16 1998 ro@suse.de
- added symlink usr/include/X11
* Thu May 28 1998 ro@suse.de
- added symlinks to linux include files
* Thu May 28 1998 bs@suse.de
- moved ".so" Links to package libc.
* Wed May 27 1998 bs@suse.de
- changed version do `date`
* Wed May 27 1998 ro@suse.de
- created specfile to build libc, shlibs, libd, libcinfo
  localedb, timezone,
- former libc renamed to libc5.
